﻿using System;
using System.Data;
using System.Configuration;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using System.Collections.Generic;
using System.Collections.Specialized;

namespace SiteExample
{
    public class CQueryString
    {
        Dictionary<string, string> _queryItems = new Dictionary<string, string>();

        public CQueryString(NameValueCollection qs)
        {
            foreach (string key in qs.AllKeys)
            {
                if (!_queryItems.ContainsKey(key.ToLower()))
                {
                    string[] values = qs.GetValues(key);
                    if (values.Length > 0)
                    {
                        _queryItems.Add(key.ToLower(), values[0]);
                    }
                }
            }
        }

        public CQueryString(string qs)
        {
            Concat(qs);
        }

        public CQueryString Concat(string qs)
        {
            if (!string.IsNullOrEmpty(qs))
            {
                string[] urlParts = qs.Split('?');
                qs = urlParts[urlParts.Length - 1];
                string[] pairs = qs.Split('&');
                foreach (string pair in pairs)
                {
                    string[] kvp = pair.Split('=');
                    if (kvp.Length == 2)
                    {
                        if (!_queryItems.ContainsKey(kvp[0].ToLower()))
                        {
                            _queryItems.Add(kvp[0].ToLower(), kvp[1]);
                        }
                    }
                }
            }
            return this;
        }

        public CQueryString Concat(NameValueCollection qs)
        {
            foreach (string key in qs.AllKeys)
            {
                if (!_queryItems.ContainsKey(key.ToLower()))
                {
                    string[] values = qs.GetValues(key);
                    if (values.Length > 0)
                    {
                        _queryItems.Add(key.ToLower(), values[0]);
                    }
                }
            }
            return this;
        }

        public CQueryString Add(string key, string value)
        {
            if (!_queryItems.ContainsKey(key.ToLower()))
                _queryItems.Add(key.ToLower(), value);
            return this;
        }

        public CQueryString Replace(string key, string value)
        {
            if (_queryItems.ContainsKey(key.ToLower()))
                Remove(key.ToLower());
            _queryItems.Add(key.ToLower(), value);
            return this;
        }

        public CQueryString Remove(string key)
        {
            if (_queryItems.ContainsKey(key.ToLower()))
                _queryItems.Remove(key.ToLower());
            return this;
        }

        public bool ContainsKey(string key)
        {
            return _queryItems.ContainsKey(key.ToLower());
        }

        public string GetKeyValue(string key)
        {
            string rc = null;
            if (_queryItems.ContainsKey(key.ToLower()))
            {
                rc = _queryItems[key.ToLower()];
            }
            return rc;
        }

        public int? GetKeyValueAsInt(string key)
        {
            int? rc = null;
            if (_queryItems.ContainsKey(key.ToLower()) && !string.IsNullOrEmpty(_queryItems[key.ToLower()]))
            {
                int tmp;
                if (int.TryParse(_queryItems[key.ToLower()], out tmp))
                {
                    rc = tmp;
                }
            }
            return rc;
        }

        public string Get()
        {
            string rc = "";
            if (_queryItems.Count > 0)
            {
                rc = "";
                foreach (KeyValuePair<string, string> kvp in _queryItems)
                {
                    if (rc == "")
                    {
                        rc += "?" + kvp.Key + "=" + kvp.Value;
                    }
                    else
                    {
                        rc += "&" + kvp.Key + "=" + kvp.Value;
                    }
                }
            }
            return rc;
        }

        public override string ToString()
        {
            return Get();
        }
    }
}
