﻿using System;
using System.Collections;
using System.Collections.Generic;
using System.Configuration;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using System.Xml.Linq;
using SiteExample.WS_IPublished;

namespace SiteExample
{
    public partial class _Default : System.Web.UI.Page
    {
        private long _contentID = 0;
        protected string Ticket { get { return null; } }
        protected string ContentTag { get { return "CONTENT"; } }
        protected string SUIDTag { get { return "SUID"; } }

        protected long ContentID
        {
            get
            {
                if (_contentID == 0)
                    _contentID = URIToContentID(ContentURI);
                return _contentID;
            }
        }

        protected bool IsHome { get { return (ContentID == URIToContentID(HomeURI)); } }

        protected string HomeURI { get { return System.Configuration.ConfigurationManager.AppSettings["homeSystemUniqueID"]; } }

        protected string ContentURI
        {
            get
            {
                if (!string.IsNullOrEmpty(Request.QueryString[ContentTag]))
                    return Request.QueryString[ContentTag];
                if (!string.IsNullOrEmpty(Request.QueryString[SUIDTag]))
                    return Request.QueryString[SUIDTag];
                return HomeURI;
            }
        }

        protected long URIToContentID(string uri)
        {
            long rc = 0;
            if (!string.IsNullOrEmpty(uri))
            {
                long.TryParse(uri.Split('_')[uri.Split('_').Length - 1], out rc);
                if (rc == 0)
                {
                    IPublished iPublished = new IPublished();
                    iPublished.UseDefaultCredentials = true;
                    try
                    {
                        rc = iPublished.LookupIDFromSUID(Ticket, uri).ContentID;
                    }
                    catch (Exception) { }
                    iPublished.Dispose();
                }
            }
            return rc;
        }

        protected string PostProcess(string input, string replace, string replacement)
        {
            try
            {
                return new System.Text.RegularExpressions.Regex("(?<=\\<\\s*(img.*src|a.*href)\\s*\\=\\s*[\"'])([\\w\\.\\/\\:]*\\/)?" + replace.Replace(".", "\\.") + "[^\\?\"']*(?=[\\?\"'].*\\>)", System.Text.RegularExpressions.RegexOptions.Multiline | System.Text.RegularExpressions.RegexOptions.IgnoreCase).Replace(input, replacement);
            }
            catch (Exception)
            {
                return input;
            }
        }

        protected void Page_Load(object sender, EventArgs e)
        {
            returnGetContentDetails contentDetails = GetContentDetails();
            if (contentDetails != null)
            {
                DisplayContent(contentDetails);
                SetMetaContent(contentDetails);
                DisplayNavigation(contentDetails);
            }
            else
            {
                // Content not found. Enter your error handling code here...
                ContentLiteral.Text = "<h3>The page you have requested could not be located.</h3>";
                DisplayNavigation(null);
            }
        }

        private returnGetContentDetails GetContentDetails()
        {
            returnGetContentDetails rc = null;
            IPublished iPublished = new IPublished();
            iPublished.UseDefaultCredentials = true;
            try
            {
                rc = iPublished.GetContentDetails(Ticket, ContentID);
            }
            catch (Exception) { }
            iPublished.Dispose();
            return rc;
        }

        private void SetMetaContent(returnGetContentDetails contentDetails)
        {
            //metaTitle.Text = HttpUtility.HtmlEncode(contentDetails.ContentTitle ?? "Cop content");
            //metaDesc.Content = HttpUtility.HtmlEncode(contentDetails.ContentDescription ?? "");
            //metaKeyword.Content = HttpUtility.HtmlEncode(contentDetails.ContentKeywords ?? "");
            //metaRobots.Content = HttpUtility.HtmlEncode(contentDetails.ContentRobots ?? "INDEX, FOLLOW");
            //LanguageLiteral.Text = ((!string.IsNullOrEmpty(contentDetails.ContentLanguage)) ? "<meta http-equiv=\"content-language\" content=\"" + HttpUtility.HtmlEncode(contentDetails.ContentLanguage) + "\" />" : "");

            metaTitle.Text = contentDetails.ContentTitle ?? "Cop content";
            metaDesc.Content = contentDetails.ContentDescription ?? "";
            metaKeyword.Content = contentDetails.ContentKeywords ?? "Diarium,Diariesystem,Diarieföring,Ärendehantering,Ärendeganteringssystem,Arkiv,Arkivering,Arkivsystem,OAIS,PSI,Publicering,CMS,Content Management System,Sheriff,Marshal,Cop";
            metaRobots.Content = contentDetails.ContentRobots ?? "INDEX, FOLLOW";
            LanguageLiteral.Text = ((!string.IsNullOrEmpty(contentDetails.ContentLanguage)) ? "<meta http-equiv=\"content-language\" content=\"" + contentDetails.ContentLanguage + "\" />" : "");
        }

        private returnDownload Download(returnGetContentDetails contentDetails)
        {
            returnDownload rc = null;
            IPublished iPublished = new IPublished();
            iPublished.UseDefaultCredentials = true;
            try
            {
                rc = iPublished.Download(Ticket, contentDetails.ContentID);
            }
            catch (Exception) { }
            iPublished.Dispose();
            return rc;
        }

        private void DisplayContent(returnGetContentDetails contentDetails)
        {
            switch (contentDetails.ContentType)
            {
                case "None": // Folder
                    break;

                case "Link":
                    if (!string.IsNullOrEmpty(contentDetails.LinkTargetURI))
                        Server.Transfer(Request.CurrentExecutionFilePath + new CQueryString(Request.QueryString).Replace(ContentTag, contentDetails.LinkTargetURI).Get());
                    else if (!string.IsNullOrEmpty(contentDetails.LinkTargetURL))
                        Response.Redirect(contentDetails.LinkTargetURL);
                    break;

                case "Document":
                case "Image":
                    {
                        returnDownload data = Download(contentDetails);
                        if (data != null)
                        {
                            Response.Clear();
                            Response.ContentType = data.MimeType;
                            Response.BinaryWrite(data.bytes);
                            Response.End();
                        }
                    }
                    break;

                case "Article":
                    ContentLiteral.Text = PostProcess(contentDetails.ArticleData, "Display.aspx", "Default.aspx");
                    break;

                case "Message":
                    ContentLiteral.Text = contentDetails.MessageData;
                    break;
            }
        }

        private void SelectTreeNode(TreeNode tn)
        {
            tn.Select();
            tn.Expand();
            TreeNode pn = tn.Parent;
            while (pn != null)
            {
                pn.Expand();
                pn = pn.Parent;
            }
        }

        private void NavigationChildNodes(IPublished iPublished, TreeNode parentNode, long parentContentID)
        {
            foreach (returnListChildContent content in iPublished.ListChildContent(null, Ticket, parentContentID))
            {
                if (string.Compare(content.ContentType, "Message", true) != 0)
                {
                    TreeNode childNode = new TreeNode(content.ContentTitle, content.ContentID.ToString());
                    if (content.ContentType == "Link")
                        childNode.NavigateUrl = ((!string.IsNullOrEmpty(content.LinkTargetURI)) ? Request.CurrentExecutionFilePath + "?" + ContentTag + "=" + content.LinkTargetURI : content.LinkTargetURL);
                    else childNode.NavigateUrl = Request.CurrentExecutionFilePath + "?" + ContentTag + "=" + content.friendlyName;
                    parentNode.ChildNodes.Add(childNode);
                    if (content.ContentID == ContentID)
                        SelectTreeNode(childNode);
                    NavigationChildNodes(iPublished, childNode, content.ContentID);
                }
            }
        }

        private void NavigationRootNodes(IPublished iPublished, long siteID)
        {
            foreach (returnListRootContent content in iPublished.ListRootContent(null, Ticket, siteID))
            {
                if (string.Compare(content.ContentType, "Message", true) != 0)
                {
                    TreeNode rootNode = new TreeNode(content.ContentTitle, content.ContentID.ToString());
                    if (content.ContentType == "Link")
                        rootNode.NavigateUrl = ((!string.IsNullOrEmpty(content.LinkTargetURI)) ? Request.CurrentExecutionFilePath + "?" + ContentTag + "=" + content.LinkTargetURI : content.LinkTargetURL);
                    else rootNode.NavigateUrl = Request.CurrentExecutionFilePath + "?" + ContentTag + "=" + content.friendlyName;
                    navigationTree.Nodes.Add(rootNode);
                    if (content.ContentID == ContentID)
                        SelectTreeNode(rootNode);
                    NavigationChildNodes(iPublished, rootNode, content.ContentID);
                }
            }
        }

        private void DisplayNavigation(returnGetContentDetails contentDetails)
        {
            IPublished iPublished = new IPublished();
            iPublished.UseDefaultCredentials = true;
            try
            {
                if (contentDetails == null)
                    contentDetails = iPublished.GetContentDetails(Ticket, URIToContentID(HomeURI));
                NavigationRootNodes(iPublished, contentDetails.SiteID);
            }
            catch (Exception) { }
            iPublished.Dispose();
        }
    }
}
