﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.Odbc;
using System.IO;
using PlatformFramework;

//da6e583d-ae07-4955-956b-5fe205448f88
//
// CMS (cms)
// Version 1.0 (#33)
//
// RISE to Bloome Software AB
// RISE to Bloome Software AB, 2010-2011
//
//da6e583d-ae07-4955-956b-5fe205448f88

namespace cms.DB.IFiles
{
	/// <summary>
	/// Return value from method Download
	/// </summary>
	public struct returnDownload
	{
		public string Title;
		public string MimeType;
		public byte[] bytes;
	}
	/// <summary>
	/// Return value from method DownloadThumbnail
	/// </summary>
	public struct returnDownloadThumbnail
	{
		public string MimeType;
		public byte[] imageBytes;
	}
	/// <summary>
	/// Return value from method Upload
	/// </summary>
	public struct returnUpload
	{
		public long? imageID;
		public long? documentID;
	}
	/// <summary>
	/// Class implementing operations on:
	///     Custom object
	/// </summary>
	public class IFiles
	{
		private string _tempDir = ".";
		private bool _odbcCloseAfterUse;
		private OdbcConnection _dbConnection = null;
		private OdbcTransaction _dbTransaction = null;
		public string TempDir
		{
			get { return _tempDir; }
			set { _tempDir = value; }
		}
		public OdbcConnection DbConnection
		{
			get { return _dbConnection; }
			set { _dbConnection = value; }
		}
		public OdbcTransaction DbTransaction
		{
			get { return _dbTransaction; }
			set { _dbTransaction = value; }
		}
		public IFiles() : this((OdbcConnection)null) { }
		public IFiles(string connectionString) : this(new OdbcConnection(connectionString)) { }
		public IFiles(OdbcConnection dbConnection)
		{
			_dbConnection = dbConnection;
		}
		public IFiles(OdbcConnection dbConnection, OdbcTransaction dbTransaction)
			: this(dbConnection)
		{
			_dbTransaction = dbTransaction;
		}
		protected void DBConnect()
		{
			if (_odbcCloseAfterUse = (_dbConnection.State != ConnectionState.Open))
			{
				_dbConnection.Open();
				if (_dbConnection.Driver.ToLower().StartsWith("myodbc"))
				{
					OdbcCommand cmd = _dbConnection.CreateCommand();
					if (_dbTransaction != null) cmd.Transaction = _dbTransaction;
					cmd.CommandText = "SET sql_mode = 'ANSI'";
					cmd.ExecuteNonQuery();
				}
			}
		}
		protected void DBClose() { if (_odbcCloseAfterUse) _dbConnection.Close(); }
		protected OdbcCommand DBCreateCommand()
		{
			OdbcCommand cmd = _dbConnection.CreateCommand();
			if(_dbTransaction != null) cmd.Transaction = _dbTransaction;
			return cmd;
		}
		/// <summary>
		/// Download Image or Document blob
		/// perform custom defined operations.
		/// </summary>
		/// <param name="ticket"></param>
		/// <param name="contentID"></param>
		/// <returns>returnDownload</returns>
		public returnDownload Download(string ticket, long? contentID)
		{
			returnDownload rv = new returnDownload();
			DBConnect();
			OdbcCommand cmd = DBCreateCommand();
			PlatformFramework.Files customObject = new PlatformFramework.Files(cmd);
			rv = customObject.Download(ticket, contentID);
			cmd.Dispose();
			DBClose();
			return rv;
		}
		/// <summary>
		/// Download Image thumbnail blob
		/// perform custom defined operations.
		/// </summary>
		/// <param name="ticket"></param>
		/// <param name="contentID"></param>
		/// <returns>returnDownloadThumbnail</returns>
		public returnDownloadThumbnail DownloadThumbnail(string ticket, long? contentID)
		{
			returnDownloadThumbnail rv = new returnDownloadThumbnail();
			DBConnect();
			OdbcCommand cmd = DBCreateCommand();
			PlatformFramework.Files customObject = new PlatformFramework.Files(cmd);
			rv = customObject.DownloadThumbnail(ticket, contentID);
			cmd.Dispose();
			DBClose();
			return rv;
		}
		/// <summary>
		/// Upload Image or Document blob. Creates image thumbnail blob.
		/// perform custom defined operations.
		/// </summary>
		/// <param name="ticket"></param>
		/// <param name="siteID"></param>
		/// <param name="contentID"></param>
		/// <param name="parentID"></param>
		/// <param name="type"></param>
		/// <param name="fileName"></param>
		/// <param name="mimeType"></param>
		/// <param name="bytes"></param>
		/// <returns>returnUpload</returns>
		public returnUpload Upload(string ticket, long? siteID, long? contentID, long? parentID, string type, string fileName, string mimeType, byte[] bytes)
		{
			returnUpload rv = new returnUpload();
			DBConnect();
			OdbcCommand cmd = DBCreateCommand();
			PlatformFramework.Files customObject = new PlatformFramework.Files(cmd);
			if (fileName == null) throw new Exception("fileName must not be null!");
			if (mimeType == null) throw new Exception("mimeType must not be null!");
			if (bytes == null) throw new Exception("bytes must not be null!");
			rv = customObject.Upload(ticket, siteID, contentID, parentID, type, fileName, mimeType, bytes);
			cmd.Dispose();
			DBClose();
			return rv;
		}
	}
}
