﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Data;
using System.Data.Odbc;
using System.IO;

//da6e583d-ae07-4955-956b-5fe205448f88
//
// CMS (cms)
// Version 1.0 (#33)
//
// RISE to Bloome Software AB
// RISE to Bloome Software AB, 2010-2011
//
//da6e583d-ae07-4955-956b-5fe205448f88

namespace cms.DB.ISession
{
	/// <summary>
	/// Return value from method Start
	/// </summary>
	public struct returnStart
	{
		public string ticket;
		public long UserID;
		public string UserLogin;
		public bool UserAdministrator;
		public string UserName;
	}
	/// <summary>
	/// Return value from method End
	/// </summary>
	public struct returnEnd
	{
		public int methodReturnsNothing;
	}
	/// <summary>
	/// Return value from method Info
	/// </summary>
	public struct returnInfo
	{
		public bool IsAuthenticated;
		public string UserGUID;
		public long UserID;
		public string UserLogin;
		public bool UserAdministrator;
		public string UserName;
		public string Ticket;
	}
	/// <summary>
	/// Return value from method ChangePassword
	/// </summary>
	public struct returnChangePassword
	{
		public int methodReturnsNothing;
	}
	/// <summary>
	/// Class implementing operations on:
	///     Custom object
	/// </summary>
	public class ISession
	{
		private string _tempDir = ".";
		private bool _odbcCloseAfterUse;
		private OdbcConnection _dbConnection = null;
		private OdbcTransaction _dbTransaction = null;
		public string TempDir
		{
			get { return _tempDir; }
			set { _tempDir = value; }
		}
		public OdbcConnection DbConnection
		{
			get { return _dbConnection; }
			set { _dbConnection = value; }
		}
		public OdbcTransaction DbTransaction
		{
			get { return _dbTransaction; }
			set { _dbTransaction = value; }
		}
		public ISession() : this((OdbcConnection)null) { }
		public ISession(string connectionString) : this(new OdbcConnection(connectionString)) { }
		public ISession(OdbcConnection dbConnection)
		{
			_dbConnection = dbConnection;
		}
		public ISession(OdbcConnection dbConnection, OdbcTransaction dbTransaction)
			: this(dbConnection)
		{
			_dbTransaction = dbTransaction;
		}
		protected void DBConnect()
		{
			if (_odbcCloseAfterUse = (_dbConnection.State != ConnectionState.Open))
			{
				_dbConnection.Open();
				if (_dbConnection.Driver.ToLower().StartsWith("myodbc"))
				{
					OdbcCommand cmd = _dbConnection.CreateCommand();
					if (_dbTransaction != null) cmd.Transaction = _dbTransaction;
					cmd.CommandText = "SET sql_mode = 'ANSI'";
					cmd.ExecuteNonQuery();
				}
			}
		}
		protected void DBClose() { if (_odbcCloseAfterUse) _dbConnection.Close(); }
		protected OdbcCommand DBCreateCommand()
		{
			OdbcCommand cmd = _dbConnection.CreateCommand();
			if(_dbTransaction != null) cmd.Transaction = _dbTransaction;
			return cmd;
		}
		/// <summary>
		/// Starts a new session by allocating a ticket
		/// runs a sequence of connected methods: LoginPwd, CurrentUser.
		/// </summary>
		/// <param name="login"></param>
		/// <param name="password"></param>
		/// <param name="persistent"></param>
		/// <returns>returnStart</returns>
		public returnStart Start(string login, string password, bool persistent)
		{
			returnStart rv = new returnStart();
			List<returnStart> rvl = new List<returnStart>();
			returnStart crv = new returnStart();
			bool crvUsed = false;
			cms.DB.PPlatform.PPlatform PPlatformObj = new cms.DB.PPlatform.PPlatform(DbConnection, DbTransaction);
			if (login == null) throw new Exception("login must not be null!");
			if (password == null) throw new Exception("password must not be null!");
			cms.DB.PPlatform.returnLoginPwd prvLoginPwd = PPlatformObj.LoginPwd(login, password, persistent);
			crv.ticket = prvLoginPwd.ticket;
			crvUsed = true;
			cms.DB.PPlatform.returnCurrentUser prvCurrentUser = PPlatformObj.CurrentUser(prvLoginPwd.ticket);
			crv.UserID = prvCurrentUser.UserID;
			crv.UserLogin = prvCurrentUser.UserLogin;
			crv.UserAdministrator = prvCurrentUser.UserAdministrator;
			crv.UserName = prvCurrentUser.UserName;
			crvUsed = true;
			if(crvUsed) rvl.Add(crv);
			rv = (rvl.Count>0 ? rvl[0] : new returnStart());
			return rv;
		}
		/// <summary>
		/// Terminates a session by cancelling the session ticket
		/// runs a sequence of connected methods: Logout.
		/// </summary>
		/// <param name="ticket"></param>
		/// <returns>returnEnd</returns>
		public returnEnd End(string ticket)
		{
			returnEnd rv = new returnEnd();
			List<returnEnd> rvl = new List<returnEnd>();
			returnEnd crv = new returnEnd();
			bool crvUsed = false;
			cms.DB.PPlatform.PPlatform PPlatformObj = new cms.DB.PPlatform.PPlatform(DbConnection, DbTransaction);
			cms.DB.PPlatform.returnLogout prvLogout = PPlatformObj.Logout(ticket);
			if(crvUsed) rvl.Add(crv);
			rv = (rvl.Count>0 ? rvl[0] : new returnEnd());
			return rv;
		}
		/// <summary>
		/// Allows a user to retrieve his/her own user account info.
		/// runs a sequence of connected methods: CurrentUser.
		/// </summary>
		/// <param name="ticket"></param>
		/// <returns>returnInfo</returns>
		public returnInfo Info(string ticket)
		{
			returnInfo rv = new returnInfo();
			List<returnInfo> rvl = new List<returnInfo>();
			returnInfo crv = new returnInfo();
			bool crvUsed = false;
			cms.DB.PPlatform.PPlatform PPlatformObj = new cms.DB.PPlatform.PPlatform(DbConnection, DbTransaction);
			cms.DB.PPlatform.returnCurrentUser prvCurrentUser = PPlatformObj.CurrentUser(ticket);
			crv.IsAuthenticated = prvCurrentUser.IsAuthenticated;
			crv.UserID = prvCurrentUser.UserID;
			crv.UserLogin = prvCurrentUser.UserLogin;
			crv.UserAdministrator = prvCurrentUser.UserAdministrator;
			crv.UserName = prvCurrentUser.UserName;
			crv.Ticket = prvCurrentUser.Ticket;
			crv.UserGUID = prvCurrentUser.UserGUID;
			crvUsed = true;
			if(crvUsed) rvl.Add(crv);
			rv = (rvl.Count>0 ? rvl[0] : new returnInfo());
			return rv;
		}
		/// <summary>
		/// Changes the curre
		/// runs a sequence of connected methods: CurrentUser, GetUser, PasswordEncode, IsEqualString, SaveUser.
		/// </summary>
		/// <param name="ticket"></param>
		/// <param name="oldPassword"></param>
		/// <param name="newPassword"></param>
		/// <returns>returnChangePassword</returns>
		public returnChangePassword ChangePassword(string ticket, string oldPassword, string newPassword)
		{
			returnChangePassword rv = new returnChangePassword();
			List<returnChangePassword> rvl = new List<returnChangePassword>();
			returnChangePassword crv = new returnChangePassword();
			bool crvUsed = false;
			cms.DB.PPlatform.PPlatform PPlatformObj = new cms.DB.PPlatform.PPlatform(DbConnection, DbTransaction);
			cms.DB.PDatabase.PDatabase PDatabaseObj = new cms.DB.PDatabase.PDatabase(DbConnection, DbTransaction);
			cms.DB.IBasics.IBasics IBasicsObj = new cms.DB.IBasics.IBasics(DbConnection, DbTransaction);
			if (oldPassword == null) throw new Exception("oldPassword must not be null!");
			cms.DB.PPlatform.returnCurrentUser prvCurrentUser = PPlatformObj.CurrentUser(ticket);
			if (prvCurrentUser.IsAuthenticated == true)
			{
				cms.DB.PDatabase.returnGetUser prvGetUser = PDatabaseObj.GetUser(prvCurrentUser.UserID);
				cms.DB.PPlatform.returnPasswordEncode prvPasswordEncode = PPlatformObj.PasswordEncode(oldPassword);
				cms.DB.IBasics.returnIsEqualString prvIsEqualString = IBasicsObj.IsEqualString(prvGetUser.PasswordMD5, prvPasswordEncode.MD5encoded);
				if (prvIsEqualString.isEqual == true)
				{
					cms.DB.PDatabase.returnSaveUser prvSaveUser = PDatabaseObj.SaveUser(prvGetUser.ID, prvGetUser.Login, prvGetUser.Name, prvGetUser.Administrator, newPassword);
				}
			}
			if(crvUsed) rvl.Add(crv);
			rv = (rvl.Count>0 ? rvl[0] : new returnChangePassword());
			return rv;
		}
	}
}
