DELIMITER GO
SET SESSION sql_mode = 'ANSI';
GO -- 'end-of-command
DROP PROCEDURE IF EXISTS "sp_install_rise_model";
GO -- 'end-of-command
CREATE PROCEDURE "sp_install_rise_model"()
BEGIN
	DECLARE "model_id" INT;
	DECLARE "log_id" INT;
	DECLARE "completed_timestamp" TIMESTAMP;
	DECLARE "start_timestamp" TIMESTAMP DEFAULT CURRENT_TIMESTAMP;
	CREATE TABLE IF NOT EXISTS "t_rise_u_model"(
		"c_id" INT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
		"c_u_name" VARCHAR(50) NULL, 
		"c_u_prefix" VARCHAR(10) NULL, 
		"c_u_guid" VARCHAR(50) NULL, 
		"c_u_version" INT NOT NULL, 
		"c_u_versionSequenceNumber" INT NOT NULL, 
		CONSTRAINT "ix_rise_u_model_u_guid" UNIQUE ("c_u_guid", "c_u_name", "c_u_prefix")
	) ENGINE = InnoDB;
	CREATE TABLE IF NOT EXISTS "t_rise_u_log"(
		"c_id" INT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
		"c_r_model" INT NOT NULL, 
		"c_u_sequenceNumber" INT NOT NULL, 
		"c_u_timeStamp" TIMESTAMP NULL DEFAULT CURRENT_TIMESTAMP, 
		"c_u_xml" TEXT NULL, 
		CONSTRAINT "ix_rise_u_log_i_modelSN" UNIQUE ("c_r_model", "c_u_sequenceNumber"), 
		CONSTRAINT "fk_rise_u_log_r_model" FOREIGN KEY ("c_r_model") REFERENCES "t_rise_u_model" ("c_id") ON DELETE CASCADE ON UPDATE CASCADE
	) ENGINE = InnoDB;
	CREATE TABLE IF NOT EXISTS "t_rise_u_sublog"(
		"c_id" INT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
		"c_r_log" INT NOT NULL, 
		"c_u_subNumber" INT NOT NULL, 
		"c_u_timeStamp" TIMESTAMP NOT NULL DEFAULT CURRENT_TIMESTAMP, 
		CONSTRAINT "ix_rise_u_sublog_i_logSN" UNIQUE ("c_r_log", "c_u_subNumber"), 
		CONSTRAINT "fk_rise_u_sublog_r_log" FOREIGN KEY ("c_r_log") REFERENCES "t_rise_u_log" ("c_id") ON DELETE CASCADE ON UPDATE CASCADE
	) ENGINE = InnoDB;
	CREATE TABLE IF NOT EXISTS "t_rise_u_object"(
		"c_id" INT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
		"c_u_tableName" VARCHAR(50) NOT NULL, 
		"c_u_riseID" VARCHAR(50) NOT NULL, 
		"c_u_dbID" INT NOT NULL, 
		"c_u_state" VARCHAR(1) NOT NULL, 
		CONSTRAINT "ix_rise_u_object_u_tableNameriseID" UNIQUE ("c_u_tableName", "c_u_riseID"), 
		CONSTRAINT "ix_rise_u_object_u_tableNamedbID" UNIQUE ("c_u_tableName", "c_u_riseID")
	) ENGINE = InnoDB;
	IF ((SELECT COUNT(*) FROM "INFORMATION_SCHEMA"."COLUMNS" WHERE ("TABLE_NAME" = 't_rise_u_object') AND ("TABLE_SCHEMA" = DATABASE()) AND ("COLUMN_NAME" = 'c_u_state')) = 0) THEN
		BEGIN
			ALTER TABLE "t_rise_u_object" ADD COLUMN "c_u_state" VARCHAR(1) NOT NULL;
		END;
	END IF;
	SELECT "t_rise_u_model"."c_id" INTO "model_id" FROM "t_rise_u_model" WHERE ("t_rise_u_model"."c_u_guid" = 'da6e583d-ae07-4955-956b-5fe205448f88') AND ("t_rise_u_model"."c_u_name" = 'CMS') AND ("t_rise_u_model"."c_u_prefix" = 'cms');
	IF ISNULL("model_id") THEN
		BEGIN
			INSERT INTO "t_rise_u_model"("c_u_name", "c_u_prefix", "c_u_guid", "c_u_version", "c_u_versionSequenceNumber") VALUES ('CMS', 'cms', 'da6e583d-ae07-4955-956b-5fe205448f88', 0, 0);
			SELECT "t_rise_u_model"."c_id" INTO "model_id" FROM "t_rise_u_model" WHERE ("t_rise_u_model"."c_u_guid" = 'da6e583d-ae07-4955-956b-5fe205448f88') AND ("t_rise_u_model"."c_u_name" = 'CMS') AND ("t_rise_u_model"."c_u_prefix" = 'cms');
		END;
	END IF;
	/**
	 * 1: New entity Content with SUID, Type, Title, Published, SortOrder, Keywords, Description, Robots, Language, Custom, AllowMessages, Abstract
	 **/
	IF 1 THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 1);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 1, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 1);
						END;
					END IF;
					-- Create table: t_cms_u_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Content"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_SUID" VARCHAR(50) NOT NULL, 
								"c_u_Type" VARCHAR(50) NOT NULL, 
								"c_u_Title" VARCHAR(255) NOT NULL, 
								"c_u_Published" TINYINT(1) NOT NULL DEFAULT '0', 
								"c_u_SortOrder" VARCHAR(50) NULL, 
								"c_u_Keywords" VARCHAR(255) NULL, 
								"c_u_Description" VARCHAR(255) NULL, 
								"c_u_Robots" VARCHAR(50) NULL, 
								"c_u_Language" VARCHAR(50) NULL, 
								"c_u_Custom" VARCHAR(255) NULL, 
								"c_u_AllowMessages" TINYINT(1) NOT NULL DEFAULT '0', 
								"c_u_Abstract" TEXT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Content.c_u_SUID as ix_cms_u_Content_u_SUID
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" ADD CONSTRAINT "ix_cms_u_Content_u_SUID" UNIQUE KEY ("c_u_SUID");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add df_constraint: on t_cms_u_Content.c_u_Published as df_cms_u_Content_u_Published
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" MODIFY COLUMN c_u_Published TINYINT(1) NOT NULL DEFAULT '0';
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					-- Add df_constraint: on t_cms_u_Content.c_u_AllowMessages as df_cms_u_Content_u_AllowMessages
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 4)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" MODIFY COLUMN c_u_AllowMessages TINYINT(1) NOT NULL DEFAULT '0';
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 4, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 2: New entity Article with Editor, Data, Hint
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 1) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 2);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 2, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 2);
						END;
					END IF;
					-- Create table: t_cms_u_Article
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Article"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_Editor" VARCHAR(50) NULL, 
								"c_u_Data" TEXT NULL, 
								"c_u_Hint" VARCHAR(50) NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 3: New entity Site with Name, MembersOnly, RecycleBin
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 2) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 3);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 3, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 3);
						END;
					END IF;
					-- Create table: t_cms_u_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Site"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_Name" VARCHAR(255) NOT NULL, 
								"c_u_MembersOnly" TINYINT(1) NOT NULL DEFAULT '0', 
								"c_u_RecycleBin" TINYINT(1) NOT NULL DEFAULT '0'
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Site.c_u_Name as ix_cms_u_Site_u_Name
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Site" ADD CONSTRAINT "ix_cms_u_Site_u_Name" UNIQUE KEY ("c_u_Name");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add df_constraint: on t_cms_u_Site.c_u_MembersOnly as df_cms_u_Site_u_MembersOnly
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Site" MODIFY COLUMN c_u_MembersOnly TINYINT(1) NOT NULL DEFAULT '0';
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					-- Add df_constraint: on t_cms_u_Site.c_u_RecycleBin as df_cms_u_Site_u_RecycleBin
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 4)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Site" MODIFY COLUMN c_u_RecycleBin TINYINT(1) NOT NULL DEFAULT '0';
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 4, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 4: New entity User with GUID, Login, Name, Administrator, PasswordMD5
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 3) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 4);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 4, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 4);
						END;
					END IF;
					-- Create table: t_cms_u_User
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_User"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_GUID" VARCHAR(50) NOT NULL, 
								"c_u_Login" VARCHAR(100) NOT NULL, 
								"c_u_Name" VARCHAR(100) NOT NULL, 
								"c_u_Administrator" TINYINT(1) NOT NULL, 
								"c_u_PasswordMD5" VARCHAR(50) NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_User.c_u_GUID as ix_cms_u_User_u_GUID
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_User" ADD CONSTRAINT "ix_cms_u_User_u_GUID" UNIQUE KEY ("c_u_GUID");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_User.c_u_Login as ix_cms_u_User_u_Login
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_User" ADD CONSTRAINT "ix_cms_u_User_u_Login" UNIQUE KEY ("c_u_Login");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 5: New entity Member with Edit
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 4) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 5);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 5, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 5);
						END;
					END IF;
					-- Create table: t_cms_u_Member
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Member"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_Edit" TINYINT(1) NOT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 6: New entity Document with MimeType, Data
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 5) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 6);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 6, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 6);
						END;
					END IF;
					-- Create table: t_cms_u_Document
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Document"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_MimeType" VARCHAR(100) NOT NULL, 
								"c_u_Data" LONGBLOB NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 7: New entity Image with MimeType, Data, Width, Height, Thumbnail, Alternative
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 6) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 7);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 7, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 7);
						END;
					END IF;
					-- Create table: t_cms_u_Image
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Image"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_MimeType" VARCHAR(100) NOT NULL, 
								"c_u_Data" LONGBLOB NULL, 
								"c_u_Width" BIGINT NOT NULL, 
								"c_u_Height" BIGINT NOT NULL, 
								"c_u_Thumbnail" LONGBLOB NULL, 
								"c_u_Alternative" VARCHAR(255) NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 8: New entity Link with TargetURI, TargetURL
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 7) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 8);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 8, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 8);
						END;
					END IF;
					-- Create table: t_cms_u_Link
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Link"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_TargetURI" VARCHAR(255) NULL, 
								"c_u_TargetURL" VARCHAR(255) NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 9: New entity Message with Source, Data
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 8) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 9);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 9, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 9);
						END;
					END IF;
					-- Create table: t_cms_u_Message
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Message"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_Source" VARCHAR(50) NULL, 
								"c_u_Data" TEXT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 10: New entity Session with StartDate, Ticket, EndDate
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 9) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 10);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 10, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 10);
						END;
					END IF;
					-- Create table: t_cms_u_Session
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Session"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_StartDate" DATETIME NOT NULL, 
								"c_u_Ticket" VARCHAR(50) NOT NULL, 
								"c_u_EndDate" DATETIME NOT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Session.c_u_Ticket as ix_cms_u_Session_u_Ticket
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Session" ADD CONSTRAINT "ix_cms_u_Session_u_Ticket" UNIQUE KEY ("c_u_Ticket");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 11: New entity Log with EditedDate, EditedBy
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 10) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 11);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 11, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 11);
						END;
					END IF;
					-- Create table: t_cms_u_Log
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_Log"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_EditedDate" DATETIME NOT NULL, 
								"c_u_EditedBy" VARCHAR(100) NOT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 12: New entity ArticleHint with Name
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 11) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 12);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 12, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 12);
						END;
					END IF;
					-- Create table: t_cms_u_ArticleHint
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE TABLE "t_cms_u_ArticleHint"(
								"c_id" BIGINT NOT NULL AUTO_INCREMENT PRIMARY KEY, 
								"c_u_Name" VARCHAR(50) NOT NULL
							) ENGINE = InnoDB;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 13: New relation ContentArticle
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 12) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 13);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 13, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 13);
						END;
					END IF;
					-- Add column: t_cms_u_Article.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Article" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Article.c_r_Content as ix_cms_u_Article_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Article" ADD CONSTRAINT "ix_cms_u_Article_r_Content" UNIQUE KEY ("c_r_Content");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Article.c_r_Content as fk_cms_u_Article_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Article" ADD CONSTRAINT "fk_cms_u_Article_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 14: New relation SiteContent
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 13) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 14);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 14, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 14);
						END;
					END IF;
					-- Add column: t_cms_u_Content.c_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" ADD COLUMN "c_r_Site" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Content.c_r_Site as fk_cms_u_Content_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" ADD CONSTRAINT "fk_cms_u_Content_r_Site" FOREIGN KEY ("c_r_Site") REFERENCES "t_cms_u_Site" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 15: New relation ParentContent
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 14) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 15);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 15, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 15);
						END;
					END IF;
					-- Add column: t_cms_u_Content.c_r_Parent
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" ADD COLUMN "c_r_Parent" BIGINT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Content.c_r_Parent as fk_cms_u_Content_r_Parent
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Content" ADD CONSTRAINT "fk_cms_u_Content_r_Parent" FOREIGN KEY ("c_r_Parent") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 16: New relation UserMember
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 15) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 16);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 16, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 16);
						END;
					END IF;
					-- Add column: t_cms_u_Member.c_r_User
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Member" ADD COLUMN "c_r_User" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Member.c_r_User as fk_cms_u_Member_r_User
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Member" ADD CONSTRAINT "fk_cms_u_Member_r_User" FOREIGN KEY ("c_r_User") REFERENCES "t_cms_u_User" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 17: New relation SiteMember
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 16) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 17);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 17, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 17);
						END;
					END IF;
					-- Add column: t_cms_u_Member.c_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Member" ADD COLUMN "c_r_Site" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Member.c_r_Site as fk_cms_u_Member_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Member" ADD CONSTRAINT "fk_cms_u_Member_r_Site" FOREIGN KEY ("c_r_Site") REFERENCES "t_cms_u_Site" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 18: New relation ContentDocument
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 17) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 18);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 18, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 18);
						END;
					END IF;
					-- Add column: t_cms_u_Document.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Document" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Document.c_r_Content as ix_cms_u_Document_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Document" ADD CONSTRAINT "ix_cms_u_Document_r_Content" UNIQUE KEY ("c_r_Content");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Document.c_r_Content as fk_cms_u_Document_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Document" ADD CONSTRAINT "fk_cms_u_Document_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 19: New relation ContentImage
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 18) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 19);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 19, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 19);
						END;
					END IF;
					-- Add column: t_cms_u_Image.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Image" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Image.c_r_Content as ix_cms_u_Image_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Image" ADD CONSTRAINT "ix_cms_u_Image_r_Content" UNIQUE KEY ("c_r_Content");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Image.c_r_Content as fk_cms_u_Image_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Image" ADD CONSTRAINT "fk_cms_u_Image_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 20: New relation ContentLink
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 19) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 20);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 20, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 20);
						END;
					END IF;
					-- Add column: t_cms_u_Link.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Link" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Link.c_r_Content as ix_cms_u_Link_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Link" ADD CONSTRAINT "ix_cms_u_Link_r_Content" UNIQUE KEY ("c_r_Content");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Link.c_r_Content as fk_cms_u_Link_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Link" ADD CONSTRAINT "fk_cms_u_Link_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 21: New relation ContentMessage
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 20) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 21);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 21, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 21);
						END;
					END IF;
					-- Add column: t_cms_u_Message.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Message" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add ix_constraint: on t_cms_u_Message.c_r_Content as ix_cms_u_Message_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Message" ADD CONSTRAINT "ix_cms_u_Message_r_Content" UNIQUE KEY ("c_r_Content");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Message.c_r_Content as fk_cms_u_Message_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 3)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Message" ADD CONSTRAINT "fk_cms_u_Message_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 3, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 22: New relation UserSession
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 21) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 22);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 22, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 22);
						END;
					END IF;
					-- Add column: t_cms_u_Session.c_r_User
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Session" ADD COLUMN "c_r_User" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Session.c_r_User as fk_cms_u_Session_r_User
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Session" ADD CONSTRAINT "fk_cms_u_Session_r_User" FOREIGN KEY ("c_r_User") REFERENCES "t_cms_u_User" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 23: New relation ContentLog
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 22) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 23);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 23, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 23);
						END;
					END IF;
					-- Add column: t_cms_u_Log.c_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Log" ADD COLUMN "c_r_Content" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_Log.c_r_Content as fk_cms_u_Log_r_Content
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_Log" ADD CONSTRAINT "fk_cms_u_Log_r_Content" FOREIGN KEY ("c_r_Content") REFERENCES "t_cms_u_Content" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 24: New relation SiteArticleHint
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 23) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 24);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 24, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 24);
						END;
					END IF;
					-- Add column: t_cms_u_ArticleHint.c_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_ArticleHint" ADD COLUMN "c_r_Site" BIGINT NOT NULL;
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					-- Add fk_constraint: on t_cms_u_ArticleHint.c_r_Site as fk_cms_u_ArticleHint_r_Site
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 2)) = 0) THEN
						BEGIN
							ALTER TABLE "t_cms_u_ArticleHint" ADD CONSTRAINT "fk_cms_u_ArticleHint_r_Site" FOREIGN KEY ("c_r_Site") REFERENCES "t_cms_u_Site" ("c_id");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 2, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 25: New Member index UserSite
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 24) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 25);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 25, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 25);
						END;
					END IF;
					-- Create index: idx_cms_u_Member_UserSite
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE UNIQUE INDEX "idx_cms_u_Member_UserSite" ON "t_cms_u_Member" ("c_r_User", "c_r_Site");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 26: New ArticleHint index SiteName
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 25) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 26);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 26, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 26);
						END;
					END IF;
					-- Create index: idx_cms_u_ArticleHint_SiteName
					IF ((SELECT COUNT(*) FROM "t_rise_u_sublog" WHERE ("c_r_log" = "log_id") AND ("c_u_subNumber" = 1)) = 0) THEN
						BEGIN
							CREATE UNIQUE INDEX "idx_cms_u_ArticleHint_SiteName" ON "t_cms_u_ArticleHint" ("c_r_Site", "c_u_Name");
							INSERT INTO "t_rise_u_sublog"("c_r_log", "c_u_subNumber", "c_u_timeStamp") VALUES ("log_id", 1, NOW());
						END;
					END IF;
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 27: New instances of entity Content
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 26) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 27);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 27, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 27);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 28: New instances of entity Article
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 27) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 28);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 28, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 28);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 29: New instances of entity Site
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 28) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 29);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 29, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 29);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 30: New instances of entity User
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 29) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 30);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 30, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 30);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 31: New instances of relation ContentArticle
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 30) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 31);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 31, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 31);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 32: New instances of relation SiteContent
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 31) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 32);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 32, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 32);
						END;
					END IF;
					/** RISE New instance operation enqueued! */
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	/**
	 * 33: Release point - Created from snapshot of model CMS (cms,f3e574e9-efe6-47ea-89da-66251a03f33d) at evolution #38
	 **/
	IF ((SELECT COUNT(*) FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 32) AND (NOT ISNULL("t_rise_u_log"."c_u_timeStamp"))) = 1) THEN
		BEGIN
			SELECT NULL, NULL INTO "log_id", "completed_timestamp";
			SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 33);
			IF (ISNULL("log_id") OR ISNULL("completed_timestamp")) THEN
				BEGIN
					IF ISNULL("log_id") THEN
						BEGIN
							INSERT INTO "t_rise_u_log"("c_r_model", "c_u_sequenceNumber", "c_u_timeStamp") VALUES ("model_id", 33, NULL);
							SELECT "c_id", "c_u_timeStamp" INTO "log_id", "completed_timestamp" FROM "t_rise_u_log" WHERE ("t_rise_u_log"."c_r_model" = "model_id") AND ("t_rise_u_log"."c_u_sequenceNumber" = 33);
						END;
					END IF;
					UPDATE "t_rise_u_model" SET "c_u_version" = 1, "c_u_versionSequenceNumber" = 33 WHERE (("c_u_prefix" = 'cms') AND ("c_u_guid" = 'da6e583d-ae07-4955-956b-5fe205448f88'));
					UPDATE "t_rise_u_log" SET "c_u_timeStamp" = NOW() WHERE ("c_id" = "log_id");
				END;
			END IF;
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '1')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_Site"("c_u_Name", "c_u_MembersOnly", "c_u_RecycleBin") VALUES ('__RECYCLE_BIN__', '0', '0');
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_Site', '1', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_Site"("c_u_Name", "c_u_MembersOnly", "c_u_RecycleBin") VALUES ('Test site', '0', '0');
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_Site', '2', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '3')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_Site"("c_u_Name", "c_u_MembersOnly", "c_u_RecycleBin") VALUES ('Resources', '0', '0');
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_Site', '3', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_User"("c_u_GUID", "c_u_Login", "c_u_Name", "c_u_Administrator") VALUES ('6520D69B-D4BA-4251-BFAD-840DA2ABAC4D', 'admin', 'Built-in Administrator', '1');
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_User', '2', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_Content"("c_u_SUID", "c_u_Type", "c_u_Title", "c_u_Published", "c_u_AllowMessages", "c_r_Site") VALUES ('HOME', 'Article', 'Welcome to RISE.CMS', '0', '0', (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')));
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_Content', '2', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Article') AND ("c_u_riseID" = '1')) = 0) THEN
		BEGIN
			INSERT INTO "t_cms_u_Article"("c_r_Content") VALUES ((SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			INSERT INTO "t_rise_u_object"("c_u_tableName", "c_u_riseID", "c_u_dbID", "c_u_state") SELECT 't_cms_u_Article', '1', LAST_INSERT_ID(), 'i';
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '1') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_Site" SET "c_u_Name" = '__RECYCLE_BIN__' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '1')));
			UPDATE "t_cms_u_Site" SET "c_u_MembersOnly" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '1')));
			UPDATE "t_cms_u_Site" SET "c_u_RecycleBin" = '1' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '1')));
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_Site" SET "c_u_Name" = 'Test site' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Site" SET "c_u_MembersOnly" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Site" SET "c_u_RecycleBin" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')));
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '3') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_Site" SET "c_u_Name" = 'Resources' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '3')));
			UPDATE "t_cms_u_Site" SET "c_u_MembersOnly" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '3')));
			UPDATE "t_cms_u_Site" SET "c_u_RecycleBin" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '3')));
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_User" SET "c_u_GUID" = '6520D69B-D4BA-4251-BFAD-840DA2ABAC4D' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_User" SET "c_u_Login" = 'admin' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_User" SET "c_u_Name" = 'Built-in Administrator' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_User" SET "c_u_Administrator" = '1' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_User" SET "c_u_PasswordMD5" = '5DB841236C2A297CAD1D48791FAB9C2E' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_User') AND ("c_u_riseID" = '2')));
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_Content" SET "c_u_SUID" = 'HOME' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_Type" = 'Article' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_Title" = 'Welcome to RISE.CMS' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_Published" = '1' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_SortOrder" = '0010' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_AllowMessages" = '0' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_u_Abstract" = 'RISE.CMS installation homepage' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
			UPDATE "t_cms_u_Content" SET "c_r_Site" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Site') AND ("c_u_riseID" = '2')) WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')));
		END;
	END IF;
	IF ((SELECT COUNT(*) FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Article') AND ("c_u_riseID" = '1') AND ("c_u_state" = 'i')) = 1) THEN
		BEGIN
			UPDATE "t_cms_u_Article" SET "c_u_Editor" = 'Xinha' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Article') AND ("c_u_riseID" = '1')));
			UPDATE "t_cms_u_Article" SET "c_u_Data" = '<h1>Welcome to RISE.CMS</h1><p>If you are able to see this page your installation is up and running.</p><p>Now you may proceed, for instance, with:</p><ul><li>Content authoring in the RISE.CMS editor.</li><li>Adjusting or fixing a better site template.</li><li>Integrating and modifying RISE.CMS itself.</li></ul><p>&nbsp;</p><p>Good luck!</p>' WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Article') AND ("c_u_riseID" = '1')));
			UPDATE "t_cms_u_Article" SET "c_r_Content" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Content') AND ("c_u_riseID" = '2')) WHERE ("c_id" = (SELECT "c_u_dbID" FROM "t_rise_u_object" WHERE ("c_u_tableName" = 't_cms_u_Article') AND ("c_u_riseID" = '1')));
		END;
	END IF;
	-- End
	SELECT NOW() - start_timestamp AS TimeTaken;
END;
GO -- 'end-of-command
CALL sp_install_rise_model;
GO -- 'end-of-command
DELIMITER ;
-- End
