﻿using System;
using System.Data.Odbc;
using System.Web;
using System.IO;
using System.Drawing;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using db.Utility;
using cms.DB.PPlatform;
using cms.DB.PDatabase;
using cms.DB.IBasics;
using cms.DB.IFiles;
using cms.DB.ICredentials;

namespace PlatformFramework
{
    public class Files
    {
        private OdbcCommand _cmd = null;
        public Files(OdbcCommand cmd)
        {
            _cmd = cmd;
        }
        public returnDownload Download(string ticket, long? contentID)
        {
            returnDownload rv = new returnDownload();
            PDatabase db = new PDatabase(_cmd.Connection);
            db.TempDir = HttpContext.Current.Server.MapPath(".") + "\\App_Data";
            if (contentID.HasValue)
            {
                PPlatform pp = new PPlatform(_cmd.Connection);
                returnContentTypes types = pp.ContentTypes();
                returnGetContent content = db.GetContent(contentID.Value);
                byte[] bytes = new byte[0];
                if (content.Type == types.Image)
                {
                    returnGetImageByContent img = db.GetImageByContent(contentID.Value);
                    bytes = db.GetImageData(img.ImageID).Data;
                    rv.MimeType = img.ImageMimeType;
                }
                else if (content.Type == types.Document)
                {
                    returnGetDocumentByContent doc = db.GetDocumentByContent(contentID.Value);
                    bytes = db.GetDocumentData(doc.DocumentID).Data;
                    rv.MimeType = doc.DocumentMimeType;
                }

                rv.Title = content.Title;
                rv.bytes = bytes;
            }
            return rv;
        }
        public returnDownloadThumbnail DownloadThumbnail(string ticket, long? contentID)
        {
            returnDownloadThumbnail rv = new returnDownloadThumbnail();
            PDatabase db = new PDatabase(_cmd.Connection);
            db.TempDir = HttpContext.Current.Server.MapPath(".") + "\\App_Data";
            PPlatform pf = new PPlatform(_cmd.Connection);

            if (contentID.HasValue)
            {
                returnThumbnails thumbs = pf.Thumbnails();
                returnGetImageByContent img = db.GetImageByContent(contentID.Value);
                rv.imageBytes = db.GetImageThumbnail(img.ImageID).Thumbnail;
                rv.MimeType = thumbs.mimeType;
            }
            return rv;
        }
        public returnUpload Upload(string ticket, long? siteID, long? contentID, long? parentID, string type, string fileName, string mimeType, byte[] bytes)
        {
            returnUpload rv = new returnUpload();
            PDatabase db = new PDatabase(_cmd.Connection);
            db.TempDir = HttpContext.Current.Server.MapPath(".") + "\\App_Data";
            PPlatform pf = new PPlatform(_cmd.Connection);
            returnCurrentUser user = pf.CurrentUser(ticket);
            returnContentTypes ct = pf.ContentTypes();

            FileInfo finfo = new FileInfo(fileName);
            returnGetContent curContent = new returnGetContent();
            if (contentID.HasValue)
            {   // existing content can't change type
                curContent = db.GetContent(contentID.Value);
                type = curContent.Type;
            }
            if (string.IsNullOrEmpty(mimeType))
            {   // try find a default mime type
                mimeType = pf.ImageMimeType(finfo.Name, "").mimeType;
            }
            if (string.IsNullOrEmpty(type))
            {   // is this an image?
                type = (pf.ImageMimeType(finfo.Name, mimeType).isImage ? ct.Image : ct.Document);
            }
            byte[] content = bytes;
            if (type == ct.Image)
            {
                returnCreateThumnail thumb = pf.CreateThumnail(content, mimeType);
                long? imageID = null;
                if (contentID.HasValue)
                {   // Update existing image
                    returnGetImageByContent curImg = db.GetImageByContent(contentID.Value);
                    mimeType = (string.IsNullOrEmpty(mimeType) ? curImg.ImageMimeType : mimeType);
                    imageID = db.SaveImage(curImg.ImageID, mimeType, thumb.originalWidth, thumb.originalHeight, curImg.ImageAlternative, curContent.ID, finfo.Name, curContent.SortOrder, curContent.SiteID, curContent.Published, curContent.Keywords, curContent.Description, curContent.Robots, curContent.Language, curContent.Custom, curContent.AllowMessages, curContent.Abstract, curContent.ParentID, user.UserLogin, curContent.SUID).ImageID;
                }
                else
                {   // create new image
                    imageID = db.SaveImage(imageID, mimeType, thumb.originalWidth, thumb.originalHeight, null, null, finfo.Name, curContent.SortOrder, siteID.Value, false, null, null, null, null, null, false, null, parentID, user.UserLogin, null).ImageID;
                }
                if (imageID.HasValue)
                {
                    db.SetImageData(imageID.Value, content);
                    rv.imageID = imageID;
                    if (thumb.autoGenerate)
                    {
                        db.SetImageThumbnail(imageID.Value, thumb.thumbnail);
                    }
                }
                else
                    throw new Exception("Failed to create or obtain image!");
            }
            else if (type == ct.Document)
            {
                long? documentID = null;
                if (contentID.HasValue)
                {   // Update existing document
                    returnGetDocumentByContent curDoc = db.GetDocumentByContent(contentID.Value);
                    mimeType = (string.IsNullOrEmpty(mimeType) ? curDoc.DocumentMimeType : mimeType);
                    documentID = db.SaveDocument(curDoc.DocumentID, mimeType, curContent.ID, finfo.Name, curContent.SortOrder, curContent.SiteID, curContent.Published, curContent.Keywords, curContent.Description, curContent.Robots, curContent.Language, curContent.Custom, curContent.AllowMessages, curContent.Abstract, curContent.ParentID, user.UserLogin, curContent.SUID).DocumentID;
                }
                else
                {   // create new document
                    documentID = db.SaveDocument(null, mimeType, null, finfo.Name, curContent.SortOrder, siteID.Value, false, null, null, null, null, null, false, null, parentID, user.UserLogin, null).DocumentID;
                }
                if (documentID.HasValue)
                {
                    db.SetDocumentData(documentID.Value, content);
                    rv.documentID = documentID;
                }
                else
                    throw new Exception("Failed to create or obtain document!");
            }
            else
            {
                throw new Exception("Unknown type [" + type ?? "<null>" + "]!");
            }
            return rv;
        }
    }
}