﻿using System;
using System.Data.Odbc;
using System.Web;
using System.Collections.Generic;
using db.Utility;
using cms.DB.PPlatform;
using cms.DB.PDatabase;

namespace PlatformFramework
{
    public class Security
    {
        private OdbcCommand _cmd = null;
        protected string Seed { get { return "7cb0a633-c557-4a58-964a-c17cf45d44c7"; } } /* to obfuscate password MD5 */
        public Security(OdbcCommand cmd)
        {
            _cmd = cmd;
        }
        public returnLoginPwd LoginPwd(string login, string password, bool persistent)
        {
            returnLoginPwd rv = new returnLoginPwd();
            try
            {
                rv.ticket = new Utilities(_cmd).NewSUID().SUID;
                DateTime now = DateTime.Now;
                DateTime expires = now.AddMinutes(int.Parse(System.Configuration.ConfigurationManager.AppSettings["sessionTimeout"]));
                PDatabase db = new PDatabase(_cmd.Connection);
                returnGetUserByLogin user = db.GetUserByLogin(login);

                if (!string.IsNullOrEmpty(user.PasswordMD5) && this.PasswordEncode(password).MD5encoded == user.PasswordMD5)
                {
                    db.NewSession(now, rv.ticket, user.UserID, expires);
                    Manager.SetCookie(System.Configuration.ConfigurationManager.AppSettings["cookie"], rv.ticket, expires, persistent);

                    // Cleanup expired sessions for this user
                    foreach (returnListSessionByUserExpired exs in db.ListSessionByUserExpired(null, user.UserID, now))
                    {
                        try
                        {
                            db.DeleteSession(exs.ID);
                        }
                        catch (Exception) { /* Ignore, exception raised due to concurrent cleanup */ }
                    }
                }
            }
            catch (Exception)
            {
                rv.ticket = null;
            }
            if (string.IsNullOrEmpty(rv.ticket))
            {
                throw new Exception("Login failed");
            }
            return rv;
        }
        public returnCurrentUser CurrentUser(string ticket)
        {
            returnCurrentUser rv = new returnCurrentUser();
            rv.IsAuthenticated = false;
            try
            {
                PDatabase db = new PDatabase(_cmd.Connection);
                string cookie = System.Configuration.ConfigurationManager.AppSettings["cookie"];
                string activeTicket = Manager.ActiveTicket(ticket, cookie);
                if (!string.IsNullOrEmpty(activeTicket))
                {
                    returnGetSessionByTicket session = db.GetSessionByTicket(activeTicket);
                    if (DateTime.Compare(session.SessionEndDate, DateTime.Now) >= 0)
                    {
                        returnGetUser user = db.GetUser(session.UserID);
                        rv.IsAuthenticated = true;
                        rv.SessionID = session.SessionID;
                        rv.UserID = user.ID;
                        rv.UserLogin = user.Login;
                        rv.UserAdministrator = user.Administrator;
                        rv.UserName = user.Name;
                        rv.UserGUID = user.GUID;
                        rv.Ticket = activeTicket;
                    }
                    else if (!string.IsNullOrEmpty(cookie))
                    {   // Drop cookie if set
                        Manager.KillCookie(cookie);
                    }
                }
            }
            catch (Exception)
            {
                rv.IsAuthenticated = false;
            }
            return rv;
        }
        public returnLogout Logout(string ticket)
        {
            returnLogout rv = new returnLogout();
            try
            {
                PDatabase db = new PDatabase(_cmd.Connection);
                string cookie = System.Configuration.ConfigurationManager.AppSettings["cookie"];
                string activeTicket = Manager.ActiveTicket(ticket, cookie);
                if (!string.IsNullOrEmpty(activeTicket))
                {
                    try
                    {
                        returnGetSessionByTicket session = db.GetSessionByTicket(activeTicket);
                        db.DeleteSession(session.SessionID);
                    }
                    catch (Exception)
                    {
                    }
                }
                Manager.KillCookie(cookie);
            }
            catch (Exception)
            {
            }
            return rv;
        }
        public returnMakePassword MakePassword(string newPassword, string currentPasswordMD5)
        {
            returnMakePassword rv = new returnMakePassword();
            rv.passwordMD5 = (!string.IsNullOrEmpty(newPassword) ? this.PasswordEncode(newPassword).MD5encoded : currentPasswordMD5);
            return rv;
        }
        public returnPasswordEncode PasswordEncode(string unencoded)
        {
            returnPasswordEncode rv = new returnPasswordEncode();
            rv.MD5encoded = (!string.IsNullOrEmpty(unencoded) ? BitConverter.ToString(new System.Security.Cryptography.MD5CryptoServiceProvider().ComputeHash(System.Text.Encoding.UTF8.GetBytes(unencoded + Seed))).ToUpper().Replace("-", "") : null);
            return rv;
        }
    }
}