﻿using System;
using System.Data.Odbc;
using System.Web;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using db.Utility;
using cms.DB.PPlatform;
using cms.DB.PDatabase;

namespace PlatformFramework
{
    public class Utilities
    {
        private OdbcCommand _cmd = null;
        public Utilities(OdbcCommand cmd)
        {
            _cmd = cmd;
        }
        public returnContentTypes ContentTypes()
        {
            returnContentTypes rv = new returnContentTypes();
            rv.Article = "Article";
            rv.Document = "Document";
            rv.Image = "Image";
            rv.Link = "Link";
            rv.Message = "Message";
            rv.None = "None";
            return rv;
        }
        public cms.DB.PPlatform.returnDeleteContentChildren DeleteContentChildren(long contentID)
        {
            cms.DB.PPlatform.returnDeleteContentChildren rv = new cms.DB.PPlatform.returnDeleteContentChildren();
            PDatabase db = new PDatabase(_cmd.Connection);
            db.DeleteContentChildren(contentID);
            return rv;
        }
        public returnIdVariable IdVariable(long? setID)
        {
            returnIdVariable rv = new returnIdVariable();
            rv.getID = setID;
            return rv;
        }
        public returnIdIsNull IdIsNull(long? id)
        {
            returnIdIsNull rv = new returnIdIsNull();
            rv.isNull = !id.HasValue;
            return rv;
        }
        public returnContentSortOrder ContentSortOrder(long siteID, long? parentID)
        {
            returnContentSortOrder rv = new returnContentSortOrder();
            PDatabase db = new PDatabase(_cmd.Connection);
            if (parentID.HasValue)
                rv.sortOrder = (1 + db.ListContentByParent(null, parentID).Length).ToString().PadLeft(3, '0').PadRight(4, '0');
            else
                rv.sortOrder = (1 + db.ListContentRoots(null, siteID).Length).ToString().PadLeft(3, '0').PadRight(4, '0');
            return rv;
        }
        public returnComposeFriendlyName ComposeFriendlyName(long contentID, string title)
        {
            returnComposeFriendlyName rv = new returnComposeFriendlyName();
            rv.friendlyName = new Regex("\\-{2,}").Replace(new Regex("[^\\w\\.]+").Replace(title, "-"), "-").Trim('-') + "_" + contentID.ToString();
            return rv;
        }
        public returnFindIDByFriendlyName FindIDByFriendlyName(string friendlyName)
        {
            returnFindIDByFriendlyName rv = new returnFindIDByFriendlyName();
            try
            {
                if (rv.ContentID == 0 && !string.IsNullOrEmpty(friendlyName))
                {
                    rv.ContentID = Convert.ToInt64(friendlyName.Split('_')[friendlyName.Split('_').Length - 1]);
                }
            }
            catch (Exception)
            {   // broken input, just ignore it
            }
            return rv;
        }
        public returnFindIDBySUID FindIDBySUID(string SUID)
        {
            returnFindIDBySUID rv = new returnFindIDBySUID();
            try
            {
                if (!string.IsNullOrEmpty(SUID))
                {
                    rv.ContentID = new PDatabase(_cmd.Connection).GetContentBySUID(SUID).ContentID;
                }
            }
            catch (Exception)
            {   // broken input, just ignore it
            }
            return rv;
        }
        public returnLatestLog LatestLog(long contentID)
        {
            returnLatestLog rv = new returnLatestLog();
            PDatabase db = new PDatabase(_cmd.Connection);
            returnListLatestLogByContent[] logs = db.ListLatestLogByContent(1, contentID);
            if (logs.Length > 0)
            {
                rv.ID = logs[0].ID;
                rv.EditedDate = logs[0].EditedDate;
                rv.EditedBy = logs[0].EditedBy;
            }
            return rv;
        }
        public cms.DB.PPlatform.returnSetContentChildrenSite SetContentChildrenSite(long contentID, string editedBy)
        {
            new PDatabase(_cmd.Connection).SetContentChildrenSite(contentID, editedBy);
            return new cms.DB.PPlatform.returnSetContentChildrenSite();
        }
        public returnUniqueSiteName UniqueSiteName(string newSiteName)
        {
            returnUniqueSiteName rv = new returnUniqueSiteName();
            string baseName = rv.SiteName = (!string.IsNullOrEmpty(newSiteName) ? newSiteName : "New site");
            long ctr = 0;
            List<returnListSite> sites = new List<returnListSite>(new PDatabase(_cmd.Connection).ListSite(null));
            while (sites.FindAll(delegate(returnListSite s) { return string.Compare(s.Name, rv.SiteName, true) == 0; }).Count != 0)
            {
                rv.SiteName = baseName + (++ctr).ToString();
            }
            return rv;
        }
        public returnNewSUID NewSUID()
        {
            returnNewSUID rv = new returnNewSUID();
            rv.SUID = Guid.NewGuid().ToString();
            return rv;
        }
        public returnUniqueUserLogin UniqueUserLogin(string newUserLogin)
        {
            returnUniqueUserLogin rv = new returnUniqueUserLogin();
            string baseName = rv.UserLogin = (!string.IsNullOrEmpty(newUserLogin) ? newUserLogin : "newuser");
            long ctr = 0;
            List<returnListUser> users = new List<returnListUser>(new PDatabase(_cmd.Connection).ListUser(null));
            while (users.FindIndex(delegate(returnListUser u) { return string.Compare(u.Login, rv.UserLogin, true) == 0; }) >= 0)
            {
                rv.UserLogin = baseName + (++ctr).ToString();
            }
            return rv;
        }
    }
}