﻿create or replace function "public"."f_rise_cms_altercolumn_helper" (tabns text, tabname text, colname text, newcoltype text, atttypmod int) returns bool as $$
declare
  v_attnum int;
  v_atttypmod int;
  v_typname text;
  v_query text;
  v_newcolname text;
  v_newcoltype text;
begin
  select a.attnum, a.atttypmod, d.typname into v_attnum, v_atttypmod, v_typname from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) join pg_catalog.pg_type d on (d.oid=a.atttypid) where n.nspname=tabns and t.typname=tabname and a.attname=colname;
  v_newcolname := 'd' || v_attnum || colname;
  if newcoltype = 'varchar' then v_newcoltype := 'varchar(' || (atttypmod-4) || ')'; else v_newcoltype := newcoltype; end if;
  if v_typname <> newcoltype or v_atttypmod > atttypmod then
    execute 'alter table "' || tabns || '"."' || tabname || '" rename column "' || colname || '" to "' || v_newcolname || '"';
    execute 'alter table "' || tabns || '"."' || tabname || '" add column "' || colname || '" ' || v_newcoltype;
    execute 'update "' || tabns || '"."' || tabname || '" set "' || colname || '" = cast("' || v_newcolname || '" as ' || v_newcoltype || ')';
  elsif v_atttypmod < atttypmod then
    execute 'alter table "' || tabns || '"."' || tabname || '" alter column "' || colname || '" type ' || v_newcoltype;
  end if;
  return '1';
  exception
    when data_exception then return '0';
end;
$$ language plpgsql;
create or replace function "public"."f_rise_cms"() returns integer as $$
declare
  v_model_id int;
begin
  -- Setup RISE
  if not exists(select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_rise_u_model') then
    create table "public"."t_rise_u_model"
    (
      "c_id" bigserial not null,
      constraint "pk_rise_u_model_id" primary key ("c_id"),
      "c_u_name" varchar(50),
      "c_u_prefix" varchar(10),
      "c_u_guid" varchar(50),
      "c_u_version" int not null,
      "c_u_versionSequenceNumber" int not null
    );
    alter table "public"."t_rise_u_model" add constraint "ix_rise_u_model_u_guid unique" unique ("c_u_guid");
    alter table "public"."t_rise_u_model" add constraint "ix_rise_u_model_u_prefix" unique ("c_u_prefix");
    alter table "public"."t_rise_u_model" add constraint "ix_rise_u_model_u_name" unique ("c_u_name");
  end if;
  if not exists(select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_rise_u_log') then
    create table "public"."t_rise_u_log"
    (
      "c_id" bigserial not null,
      constraint "pk_rise_u_log_id" primary key ("c_id"),
      "c_r_model" bigint not null,
      "c_u_sequenceNumber" int not null,
      "c_u_timeStamp" timestamp not null,
      "c_u_xml" text null
    );
    alter table "public"."t_rise_u_log" add constraint "fk_rise_u_log_r_model" foreign key ( "c_r_model" ) references  "public"."t_rise_u_model" ( "c_id" );
    alter table "public"."t_rise_u_log" add constraint "ix_rise_u_log_i_modelSN" unique ("c_r_model","c_u_sequenceNumber");
  end if;
  if not exists(select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_rise_u_object') then
    create table "public"."t_rise_u_object"
    (
      "c_id" bigserial not null,
      constraint "pk_rise_u_object_id" primary key ("c_id"),
      "c_u_tableName" varchar(50) not null,
      "c_u_riseID" varchar(50) not null,
      "c_u_dbID" bigint not null,
      "c_u_state" varchar(1) not null
    );
    alter table "public"."t_rise_u_object" add constraint "ix_rise_u_object_u_tableNameriseID" unique ("c_u_tableName","c_u_riseID");
    alter table "public"."t_rise_u_object" add constraint "ix_rise_u_object_u_tableNamedbID" unique ("c_u_tableName","c_u_dbID");
  end if;
  if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_rise_u_object' and  a.attname='c_u_state') then
    alter table "public"."t_rise_u_object" add column "c_u_state" varchar(1) null;
  end if;

  -- Install RISE model
  if not exists(select * from "public"."t_rise_u_model" where "c_u_prefix"='cms' and "c_u_guid"='da6e583d-ae07-4955-956b-5fe205448f88') then
    insert into "public"."t_rise_u_model" ("c_u_name","c_u_prefix","c_u_guid","c_u_version","c_u_versionSequenceNumber") values ('CMS','cms','da6e583d-ae07-4955-956b-5fe205448f88',0,0);
  end if;
  select into v_model_id c_id from "public"."t_rise_u_model" where "c_u_prefix"='cms' and "c_u_guid"='da6e583d-ae07-4955-956b-5fe205448f88';

  -- Sequence for naming primary key constraints
  if not exists(select * from pg_statio_all_sequences where schemaname='public' and relname='pk_cms_constraint_seq') then
    create sequence "public"."pk_cms_constraint_seq" start 1;
  end if;

  -- #1 New entity Content with SUID, Type, Title, Published, SortOrder, Keywords, Description, Robots, Language, Custom, AllowMessages, Abstract
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=1) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,1,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Content') then
      create table  "public"."t_cms_u_Content"
      (
        "c_id" bigserial not null,
        "c_u_SUID" varchar(50) not null,
        "c_u_Type" varchar(50) not null,
        "c_u_Title" varchar(255) not null,
        "c_u_Published" bool not null,
        "c_u_SortOrder" varchar(50) null,
        "c_u_Keywords" varchar(255) null,
        "c_u_Description" varchar(255) null,
        "c_u_Robots" varchar(50) null,
        "c_u_Language" varchar(50) null,
        "c_u_Custom" varchar(255) null,
        "c_u_AllowMessages" bool not null,
        "c_u_Abstract" text null
      );
      execute 'alter table "public"."t_cms_u_Content" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Content_u_SUID' and c.contype='u') then
      alter table "public"."t_cms_u_Content" add constraint "ix_cms_u_Content_u_SUID" unique ("c_u_SUID");
    end if;
    alter table "public"."t_cms_u_Content" alter column "c_u_Published" set default '0';
    alter table "public"."t_cms_u_Content" alter column "c_u_AllowMessages" set default '0';
  end if;

  -- #2 New entity Article with Editor, Data, Hint
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=2) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,2,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Article') then
      create table  "public"."t_cms_u_Article"
      (
        "c_id" bigserial not null,
        "c_u_Editor" varchar(50) null,
        "c_u_Data" text null,
        "c_u_Hint" varchar(50) null
      );
      execute 'alter table "public"."t_cms_u_Article" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #3 New entity Site with Name, MembersOnly, RecycleBin
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=3) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,3,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Site') then
      create table  "public"."t_cms_u_Site"
      (
        "c_id" bigserial not null,
        "c_u_Name" varchar(255) not null,
        "c_u_MembersOnly" bool not null,
        "c_u_RecycleBin" bool not null
      );
      execute 'alter table "public"."t_cms_u_Site" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Site_u_Name' and c.contype='u') then
      alter table "public"."t_cms_u_Site" add constraint "ix_cms_u_Site_u_Name" unique ("c_u_Name");
    end if;
    alter table "public"."t_cms_u_Site" alter column "c_u_MembersOnly" set default '0';
    alter table "public"."t_cms_u_Site" alter column "c_u_RecycleBin" set default '0';
  end if;

  -- #4 New entity User with GUID, Login, Name, Administrator, PasswordMD5
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=4) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,4,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_User') then
      create table  "public"."t_cms_u_User"
      (
        "c_id" bigserial not null,
        "c_u_GUID" varchar(50) not null,
        "c_u_Login" varchar(100) not null,
        "c_u_Name" varchar(100) not null,
        "c_u_Administrator" bool not null,
        "c_u_PasswordMD5" varchar(50) null
      );
      execute 'alter table "public"."t_cms_u_User" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_User_u_GUID' and c.contype='u') then
      alter table "public"."t_cms_u_User" add constraint "ix_cms_u_User_u_GUID" unique ("c_u_GUID");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_User_u_Login' and c.contype='u') then
      alter table "public"."t_cms_u_User" add constraint "ix_cms_u_User_u_Login" unique ("c_u_Login");
    end if;
  end if;

  -- #5 New entity Member with Edit
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=5) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,5,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Member') then
      create table  "public"."t_cms_u_Member"
      (
        "c_id" bigserial not null,
        "c_u_Edit" bool not null
      );
      execute 'alter table "public"."t_cms_u_Member" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #6 New entity Document with MimeType, Data
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=6) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,6,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Document') then
      create table  "public"."t_cms_u_Document"
      (
        "c_id" bigserial not null,
        "c_u_MimeType" varchar(100) not null,
        "c_u_Data" bytea null
      );
      execute 'alter table "public"."t_cms_u_Document" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #7 New entity Image with MimeType, Data, Width, Height, Thumbnail, Alternative
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=7) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,7,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Image') then
      create table  "public"."t_cms_u_Image"
      (
        "c_id" bigserial not null,
        "c_u_MimeType" varchar(100) not null,
        "c_u_Data" bytea null,
        "c_u_Width" bigint not null,
        "c_u_Height" bigint not null,
        "c_u_Thumbnail" bytea null,
        "c_u_Alternative" varchar(255) null
      );
      execute 'alter table "public"."t_cms_u_Image" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #8 New entity Link with TargetURI, TargetURL
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=8) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,8,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Link') then
      create table  "public"."t_cms_u_Link"
      (
        "c_id" bigserial not null,
        "c_u_TargetURI" varchar(255) null,
        "c_u_TargetURL" varchar(255) null
      );
      execute 'alter table "public"."t_cms_u_Link" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #9 New entity Message with Source, Data
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=9) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,9,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Message') then
      create table  "public"."t_cms_u_Message"
      (
        "c_id" bigserial not null,
        "c_u_Source" varchar(50) null,
        "c_u_Data" text null
      );
      execute 'alter table "public"."t_cms_u_Message" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #10 New entity Session with StartDate, Ticket, EndDate
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=10) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,10,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Session') then
      create table  "public"."t_cms_u_Session"
      (
        "c_id" bigserial not null,
        "c_u_StartDate" timestamp not null,
        "c_u_Ticket" varchar(50) not null,
        "c_u_EndDate" timestamp not null
      );
      execute 'alter table "public"."t_cms_u_Session" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Session_u_Ticket' and c.contype='u') then
      alter table "public"."t_cms_u_Session" add constraint "ix_cms_u_Session_u_Ticket" unique ("c_u_Ticket");
    end if;
  end if;

  -- #11 New entity Log with EditedDate, EditedBy
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=11) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,11,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_Log') then
      create table  "public"."t_cms_u_Log"
      (
        "c_id" bigserial not null,
        "c_u_EditedDate" timestamp not null,
        "c_u_EditedBy" varchar(100) not null
      );
      execute 'alter table "public"."t_cms_u_Log" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #12 New entity ArticleHint with Name
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=12) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,12,now(),null);
    if not exists (select * from pg_catalog.pg_tables where schemaname='public' and tablename='t_cms_u_ArticleHint') then
      create table  "public"."t_cms_u_ArticleHint"
      (
        "c_id" bigserial not null,
        "c_u_Name" varchar(50) not null
      );
      execute 'alter table "public"."t_cms_u_ArticleHint" add constraint "pk_cms_' || nextval('"public"."pk_cms_constraint_seq"'::regclass) || '" primary key ("c_id");';
    end if;
  end if;

  -- #13 New relation ContentArticle
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=13) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,13,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Article' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Article" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Article" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Article_r_Content' and c.contype='u') then
      alter table "public"."t_cms_u_Article" add constraint "ix_cms_u_Article_r_Content" unique ("c_r_Content");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Article_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Article" add constraint "fk_cms_u_Article_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #14 New relation SiteContent
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=14) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,14,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Content' and a.attname='c_r_Site') then
      alter table "public"."t_cms_u_Content" add column "c_r_Site" bigint null;
      alter table "public"."t_cms_u_Content" alter column "c_r_Site" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Content_r_Site' and c.contype='f') then
      alter table "public"."t_cms_u_Content" add constraint "fk_cms_u_Content_r_Site" foreign key ("c_r_Site") references "public"."t_cms_u_Site" ("c_id");
    end if;
  end if;

  -- #15 New relation ParentContent
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=15) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,15,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Content' and a.attname='c_r_Parent') then
      alter table "public"."t_cms_u_Content" add column "c_r_Parent" bigint null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Content_r_Parent' and c.contype='f') then
      alter table "public"."t_cms_u_Content" add constraint "fk_cms_u_Content_r_Parent" foreign key ("c_r_Parent") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #16 New relation UserMember
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=16) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,16,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Member' and a.attname='c_r_User') then
      alter table "public"."t_cms_u_Member" add column "c_r_User" bigint null;
      alter table "public"."t_cms_u_Member" alter column "c_r_User" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Member_r_User' and c.contype='f') then
      alter table "public"."t_cms_u_Member" add constraint "fk_cms_u_Member_r_User" foreign key ("c_r_User") references "public"."t_cms_u_User" ("c_id");
    end if;
  end if;

  -- #17 New relation SiteMember
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=17) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,17,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Member' and a.attname='c_r_Site') then
      alter table "public"."t_cms_u_Member" add column "c_r_Site" bigint null;
      alter table "public"."t_cms_u_Member" alter column "c_r_Site" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Member_r_Site' and c.contype='f') then
      alter table "public"."t_cms_u_Member" add constraint "fk_cms_u_Member_r_Site" foreign key ("c_r_Site") references "public"."t_cms_u_Site" ("c_id");
    end if;
  end if;

  -- #18 New relation ContentDocument
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=18) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,18,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Document' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Document" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Document" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Document_r_Content' and c.contype='u') then
      alter table "public"."t_cms_u_Document" add constraint "ix_cms_u_Document_r_Content" unique ("c_r_Content");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Document_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Document" add constraint "fk_cms_u_Document_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #19 New relation ContentImage
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=19) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,19,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Image' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Image" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Image" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Image_r_Content' and c.contype='u') then
      alter table "public"."t_cms_u_Image" add constraint "ix_cms_u_Image_r_Content" unique ("c_r_Content");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Image_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Image" add constraint "fk_cms_u_Image_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #20 New relation ContentLink
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=20) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,20,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Link' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Link" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Link" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Link_r_Content' and c.contype='u') then
      alter table "public"."t_cms_u_Link" add constraint "ix_cms_u_Link_r_Content" unique ("c_r_Content");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Link_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Link" add constraint "fk_cms_u_Link_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #21 New relation ContentMessage
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=21) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,21,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Message' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Message" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Message" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='ix_cms_u_Message_r_Content' and c.contype='u') then
      alter table "public"."t_cms_u_Message" add constraint "ix_cms_u_Message_r_Content" unique ("c_r_Content");
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Message_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Message" add constraint "fk_cms_u_Message_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #22 New relation UserSession
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=22) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,22,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Session' and a.attname='c_r_User') then
      alter table "public"."t_cms_u_Session" add column "c_r_User" bigint null;
      alter table "public"."t_cms_u_Session" alter column "c_r_User" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Session_r_User' and c.contype='f') then
      alter table "public"."t_cms_u_Session" add constraint "fk_cms_u_Session_r_User" foreign key ("c_r_User") references "public"."t_cms_u_User" ("c_id");
    end if;
  end if;

  -- #23 New relation ContentLog
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=23) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,23,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_Log' and a.attname='c_r_Content') then
      alter table "public"."t_cms_u_Log" add column "c_r_Content" bigint null;
      alter table "public"."t_cms_u_Log" alter column "c_r_Content" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_Log_r_Content' and c.contype='f') then
      alter table "public"."t_cms_u_Log" add constraint "fk_cms_u_Log_r_Content" foreign key ("c_r_Content") references "public"."t_cms_u_Content" ("c_id");
    end if;
  end if;

  -- #24 New relation SiteArticleHint
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=24) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,24,now(),null);
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_attribute a on (a.attstattarget = -1 and t.typrelid = a.attrelid) where n.nspname='public' and t.typname='t_cms_u_ArticleHint' and a.attname='c_r_Site') then
      alter table "public"."t_cms_u_ArticleHint" add column "c_r_Site" bigint null;
      alter table "public"."t_cms_u_ArticleHint" alter column "c_r_Site" set not null;
    end if;
    if not exists (select * from pg_catalog.pg_type t join pg_catalog.pg_namespace n on (n.oid = t.typnamespace) join pg_catalog.pg_constraint c on (c.conrelid=t.typrelid) where n.nspname='public' and c.conname='fk_cms_u_ArticleHint_r_Site' and c.contype='f') then
      alter table "public"."t_cms_u_ArticleHint" add constraint "fk_cms_u_ArticleHint_r_Site" foreign key ("c_r_Site") references "public"."t_cms_u_Site" ("c_id");
    end if;
  end if;

  -- #25 New Member index UserSite
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=25) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,25,now(),null);
    if not exists (select * from pg_catalog.pg_indexes where schemaname='public' and indexname='idx_cms_u_Member_UserSite') then
      create unique index "idx_cms_u_Member_UserSite" on "public"."t_cms_u_Member" ("c_r_User","c_r_Site");
    end if;
  end if;

  -- #26 New ArticleHint index SiteName
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=26) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,26,now(),null);
    if not exists (select * from pg_catalog.pg_indexes where schemaname='public' and indexname='idx_cms_u_ArticleHint_SiteName') then
      create unique index "idx_cms_u_ArticleHint_SiteName" on "public"."t_cms_u_ArticleHint" ("c_r_Site","c_u_Name");
    end if;
  end if;

  -- #27 New instances of entity Content
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=27) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,27,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #28 New instances of entity Article
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=28) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,28,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #29 New instances of entity Site
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=29) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,29,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #30 New instances of entity User
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=30) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,30,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #31 New instances of relation ContentArticle
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=31) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,31,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #32 New instances of relation SiteContent
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=32) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,32,now(),null);
    /* New instance operation enqueued! */
  end if;

  -- #33 Release point - Created from snapshot of model CMS (cms,f3e574e9-efe6-47ea-89da-66251a03f33d) at evolution #38
  if not exists(select * from "public"."t_rise_u_log" where "c_r_model"=v_model_id and "c_u_sequenceNumber"=33) then
    insert into "public"."t_rise_u_log" ("c_r_model","c_u_sequenceNumber","c_u_timeStamp","c_u_xml") values (v_model_id,33,now(),null);
    update "public"."t_rise_u_model" set "c_u_version"=1,"c_u_versionSequenceNumber"=33 where "c_u_prefix"='cms' and "c_u_guid"='da6e583d-ae07-4955-956b-5fe205448f88';
  end if;

  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '1') then
    insert into "public"."t_cms_u_Site" ("c_u_Name") values (N'__RECYCLE_BIN__');
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_Site','1',lastval(),'i';
    end if;
  end if;
  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '2') then
    insert into "public"."t_cms_u_Site" ("c_u_Name") values (N'Test site');
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_Site','2',lastval(),'i';
    end if;
  end if;
  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '3') then
    insert into "public"."t_cms_u_Site" ("c_u_Name") values (N'Resources');
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_Site','3',lastval(),'i';
    end if;
  end if;

  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_User' and "c_u_riseID" = '2') then
    insert into "public"."t_cms_u_User" ("c_u_GUID", "c_u_Login", "c_u_Name", "c_u_Administrator") values (N'6520D69B-D4BA-4251-BFAD-840DA2ABAC4D', N'admin', N'Built-in Administrator', '1');
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_User','2',lastval(),'i';
    end if;
  end if;

  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Content' and "c_u_riseID" = '2') then
    insert into "public"."t_cms_u_Content" ("c_u_SUID", "c_u_Type", "c_u_Title", "c_r_Site") values (N'HOME', N'Article', N'Welcome to RISE.CMS', (select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '2'));
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_Content','2',lastval(),'i';
    end if;
  end if;

  if not exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Article' and "c_u_riseID" = '1') then
    insert into "public"."t_cms_u_Article" ("c_r_Content") values ((select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Content' and "c_u_riseID" = '2'));
    if found then
      insert into "public"."t_rise_u_object" ("c_u_tableName","c_u_riseID","c_u_dbID","c_u_state") select N't_cms_u_Article','1',lastval(),'i';
    end if;
  end if;

  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '1' and "c_u_state" = 'i') then
    update "public"."t_cms_u_Site" set "c_u_Name"=N'__RECYCLE_BIN__' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='1') ;
    update "public"."t_cms_u_Site" set "c_u_MembersOnly"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='1') ;
    update "public"."t_cms_u_Site" set "c_u_RecycleBin"='1' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='1') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='1';
  end if;
  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '2' and "c_u_state" = 'i') then
    update "public"."t_cms_u_Site" set "c_u_Name"=N'Test site' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Site" set "c_u_MembersOnly"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Site" set "c_u_RecycleBin"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='2') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='2';
  end if;
  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '3' and "c_u_state" = 'i') then
    update "public"."t_cms_u_Site" set "c_u_Name"=N'Resources' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='3') ;
    update "public"."t_cms_u_Site" set "c_u_MembersOnly"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='3') ;
    update "public"."t_cms_u_Site" set "c_u_RecycleBin"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='3') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_Site' and "c_u_riseID"='3';
  end if;

  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_User' and "c_u_riseID" = '2' and "c_u_state" = 'i') then
    update "public"."t_cms_u_User" set "c_u_GUID"=N'6520D69B-D4BA-4251-BFAD-840DA2ABAC4D' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_User" set "c_u_Login"=N'admin' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_User" set "c_u_Name"=N'Built-in Administrator' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_User" set "c_u_Administrator"='1' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_User" set "c_u_PasswordMD5"=N'5DB841236C2A297CAD1D48791FAB9C2E' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_User' and "c_u_riseID"='2';
  end if;

  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Content' and "c_u_riseID" = '2' and "c_u_state" = 'i') then
    update "public"."t_cms_u_Content" set "c_u_SUID"=N'HOME' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_Type"=N'Article' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_Title"=N'Welcome to RISE.CMS' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_Published"='1' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_SortOrder"=N'0010' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_AllowMessages"='0' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_u_Abstract"=N'RISE.CMS installation homepage' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_cms_u_Content" set "c_r_Site"=(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Site' and "c_u_riseID" = '2') where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_Content' and "c_u_riseID"='2';
  end if;

  if exists(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Article' and "c_u_riseID" = '1' and "c_u_state" = 'i') then
    update "public"."t_cms_u_Article" set "c_u_Editor"=N'Xinha' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Article' and "c_u_riseID"='1') ;
    update "public"."t_cms_u_Article" set "c_u_Data"=N'<h1>Welcome to RISE.CMS</h1><p>If you are able to see this page your installation is up and running.</p><p>Now you may proceed, for instance, with:</p><ul><li>Content authoring in the RISE.CMS editor.</li><li>Adjusting or fixing a better site template.</li><li>Integrating and modifying RISE.CMS itself.</li></ul><p>&nbsp;</p><p>Good luck!</p>' where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Article' and "c_u_riseID"='1') ;
    update "public"."t_cms_u_Article" set "c_r_Content"=(select "c_u_dbID" from "public"."t_rise_u_object" where "c_u_tableName" = N't_cms_u_Content' and "c_u_riseID" = '2') where "c_id" in (select "c_u_dbID" from  "public"."t_rise_u_object" where "c_u_tableName"=N't_cms_u_Article' and "c_u_riseID"='1') ;
    update "public"."t_rise_u_object" set "c_u_state"='u' where "c_u_tableName"=N't_cms_u_Article' and "c_u_riseID"='1';
  end if;

  return 33;
end;
$$ language plpgsql;
select "public"."f_rise_cms"();
drop function "public"."f_rise_cms"();
drop function "public"."f_rise_cms_altercolumn_helper"(tabns text, tabname text, colname text, newcoltype text, atttypmod int);

