﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Web;
using System.Net;

namespace db.Utility
{
    public class Manager
    {
        /// <summary>
        /// Get ticket to use. Applies ticket no validation.
        /// </summary>
        /// <param name="Ticket"></param>
        /// <param name="cookieName"></param>
        /// <returns>Ticket or ticket passed in named cookie, or null if missing or inconsistent</returns>
        public static string ActiveTicket(string Ticket, string cookieName)
        {
            string cookieTicket = null;
            if (HttpContext.Current != null && !string.IsNullOrEmpty(cookieName))
            {
                if (HttpContext.Current.Request.Cookies[cookieName] != null)
                {
                    cookieTicket = HttpContext.Current.Request.Cookies[cookieName].Value;
                }
            }
            string activeTicket = (string.IsNullOrEmpty(Ticket) ? cookieTicket :
                (string.IsNullOrEmpty(cookieTicket) || string.Compare(cookieTicket, Ticket) == 0 ? Ticket :
                null));
            return activeTicket;
        }

        /// <summary>
        /// Create cookie in current response
        /// </summary>
        /// <param name="cookieName"></param>
        /// <param name="ticket"></param>
        /// <param name="expires"></param>
        /// <param name="persistent"></param>
        public static void SetCookie(string cookieName, string ticket, DateTime expires, bool persistent)
        {
            try
            {
                if (HttpContext.Current != null)
                {
                    HttpCookie cookie = new HttpCookie(cookieName);
                    cookie.Value = ticket;
                    if (persistent)
                        cookie.Expires = expires;
                    HttpContext.Current.Response.Cookies.Add(cookie);
                }
            }
            catch (Exception)
            {
            }
        }

        /// <summary>
        /// Pass cookie from source container to current response
        /// </summary>
        /// <param name="source"></param>
        /// <param name="cookieUrl"></param>
        /// <param name="cookieName"></param>
        public static void TransferCookie(CookieContainer source, string cookieUrl, string cookieName)
        {
            try
            {
                Cookie srcCookie = source.GetCookies(new Uri(cookieUrl))[cookieName];
                if (HttpContext.Current != null && srcCookie != null)
                {
                    HttpCookie tarCookie = new HttpCookie(srcCookie.Name, srcCookie.Value);
                    tarCookie.Expires = srcCookie.Expires;
                    HttpContext.Current.Response.Cookies.Add(tarCookie);
                }
            }
            catch (Exception)
            {
            }
        }

        /// <summary>
        /// Terminate cookie in current response
        /// </summary>
        /// <param name="cookieName"></param>
        public static void KillCookie(string cookieName)
        {
            try
            {
                if (HttpContext.Current != null)
                {
                    HttpCookie cookie = new HttpCookie(cookieName);
                    cookie.Expires = DateTime.Now.AddDays(-1);
                    HttpContext.Current.Response.Cookies.Add(cookie);
                }
            }
            catch (Exception)
            {
            }
        }
    }
}
