﻿using System;
using System.Collections.Generic;
using System.Text;

namespace db.Utility
{
    public class MimeTypeMap
    {
        public bool IsImage = false;
        public string Extension;
        public string MimeType;
        public MimeTypeMap(bool isImage, string extension, string mimeType)
        {
            IsImage = isImage;
            Extension = extension;
            MimeType = mimeType;
        }
        public MimeTypeMap(string extension, string mimeType)
            : this(false, extension, mimeType)
        {
        }
        public MimeTypeMap(string mimeType)
            : this("", mimeType)
        {
        }
        public static MimeTypeMap GetByExtension(string extension)
        {
            string cmp = extension.ToLower();
            foreach (MimeTypeMap mtm in Maps)
            {
                if (mtm.Extension.ToLower().CompareTo(cmp) == 0)
                {
                    return mtm;
                }
            }
            return new MimeTypeMap(extension, "application/octet-stream");
        }
        public static MimeTypeMap GetByMimeType(string mimeType)
        {
            string cmp = mimeType.ToLower();
            foreach (MimeTypeMap mtm in Maps)
            {
                if (mtm.MimeType.ToLower().CompareTo(cmp) == 0)
                {
                    return mtm;
                }
            }
            return new MimeTypeMap(mimeType);
        }
        public static MimeTypeMap[] Maps = 
        {
            new MimeTypeMap(".3dm","x-world/x-3dmf"),
            new MimeTypeMap(".3dmf","x-world/x-3dmf"),
            new MimeTypeMap(".a","application/octet-stream"),
            new MimeTypeMap(".aab","application/x-authorware-bin"),
            new MimeTypeMap(".aam","application/x-authorware-map"),
            new MimeTypeMap(".aas","application/x-authorware-seg"),
            new MimeTypeMap(".abc","text/vnd.abc"),
            new MimeTypeMap(".acgi","text/html"),
            new MimeTypeMap(".afl","video/animaflex"),
            new MimeTypeMap(".ai","application/postscript"),
            new MimeTypeMap(".aif","audio/aiff"),
            new MimeTypeMap(".aif","audio/x-aiff"),
            new MimeTypeMap(".aifc","audio/aiff"),
            new MimeTypeMap(".aifc","audio/x-aiff"),
            new MimeTypeMap(".aiff","audio/aiff"),
            new MimeTypeMap(".aiff","audio/x-aiff"),
            new MimeTypeMap(".aim","application/x-aim"),
            new MimeTypeMap(".aip","text/x-audiosoft-intra"),
            new MimeTypeMap(".ani","application/x-navi-animation"),
            new MimeTypeMap(".aos","application/x-nokia-9000-communicator-add-on-software"),
            new MimeTypeMap(".aps","application/mime"),
            new MimeTypeMap(".arc","application/octet-stream"),
            new MimeTypeMap(".arj","application/arj"),
            new MimeTypeMap(".arj","application/octet-stream"),
            new MimeTypeMap(".art","image/x-jg"),
            new MimeTypeMap(".asf","video/x-ms-asf"),
            new MimeTypeMap(".asm","text/x-asm"),
            new MimeTypeMap(".asp","text/asp"),
            new MimeTypeMap(".asx","application/x-mplayer2"),
            new MimeTypeMap(".asx","video/x-ms-asf"),
            new MimeTypeMap(".asx","video/x-ms-asf-plugin"),
            new MimeTypeMap(".au","audio/basic"),
            new MimeTypeMap(".au","audio/x-au"),
            new MimeTypeMap(".avi","application/x-troff-msvideo"),
            new MimeTypeMap(".avi","video/avi"),
            new MimeTypeMap(".avi","video/msvideo"),
            new MimeTypeMap(".avi","video/x-msvideo"),
            new MimeTypeMap(".avs","video/avs-video"),
            new MimeTypeMap(".bcpio","application/x-bcpio"),
            new MimeTypeMap(".bin","application/mac-binary"),
            new MimeTypeMap(".bin","application/macbinary"),
            new MimeTypeMap(".bin","application/octet-stream"),
            new MimeTypeMap(".bin","application/x-binary"),
            new MimeTypeMap(".bin","application/x-macbinary"),
            new MimeTypeMap(".bm","image/bmp"),
            new MimeTypeMap(".bmp","image/bmp"),
            new MimeTypeMap(".bmp","image/x-windows-bmp"),
            new MimeTypeMap(".boo","application/book"),
            new MimeTypeMap(".book","application/book"),
            new MimeTypeMap(".boz","application/x-bzip2"),
            new MimeTypeMap(".bsh","application/x-bsh"),
            new MimeTypeMap(".bz","application/x-bzip"),
            new MimeTypeMap(".bz2","application/x-bzip2"),
            new MimeTypeMap(".c","text/plain"),
            new MimeTypeMap(".c","text/x-c"),
            new MimeTypeMap(".c++","text/plain"),
            new MimeTypeMap(".cat","application/vnd.ms-pki.seccat"),
            new MimeTypeMap(".cc","text/plain"),
            new MimeTypeMap(".cc","text/x-c"),
            new MimeTypeMap(".ccad","application/clariscad"),
            new MimeTypeMap(".cco","application/x-cocoa"),
            new MimeTypeMap(".cdf","application/cdf"),
            new MimeTypeMap(".cdf","application/x-cdf"),
            new MimeTypeMap(".cdf","application/x-netcdf"),
            new MimeTypeMap(".cer","application/pkix-cert"),
            new MimeTypeMap(".cer","application/x-x509-ca-cert"),
            new MimeTypeMap(".cha","application/x-chat"),
            new MimeTypeMap(".chat","application/x-chat"),
            new MimeTypeMap(".class","application/java"),
            new MimeTypeMap(".class","application/java-byte-code"),
            new MimeTypeMap(".class","application/x-java-class"),
            new MimeTypeMap(".com","application/octet-stream"),
            new MimeTypeMap(".com","text/plain"),
            new MimeTypeMap(".conf","text/plain"),
            new MimeTypeMap(".cpio","application/x-cpio"),
            new MimeTypeMap(".cpp","text/x-c"),
            new MimeTypeMap(".cpt","application/mac-compactpro"),
            new MimeTypeMap(".cpt","application/x-compactpro"),
            new MimeTypeMap(".cpt","application/x-cpt"),
            new MimeTypeMap(".crl","application/pkcs-crl"),
            new MimeTypeMap(".crl","application/pkix-crl"),
            new MimeTypeMap(".crt","application/pkix-cert"),
            new MimeTypeMap(".crt","application/x-x509-ca-cert"),
            new MimeTypeMap(".crt","application/x-x509-user-cert"),
            new MimeTypeMap(".csh","application/x-csh"),
            new MimeTypeMap(".csh","text/x-script.csh"),
            new MimeTypeMap(".css","application/x-pointplus"),
            new MimeTypeMap(".css","text/css"),
            new MimeTypeMap(".cxx","text/plain"),
            new MimeTypeMap(".dcr","application/x-director"),
            new MimeTypeMap(".deepv","application/x-deepv"),
            new MimeTypeMap(".def","text/plain"),
            new MimeTypeMap(".der","application/x-x509-ca-cert"),
            new MimeTypeMap(".dif","video/x-dv"),
            new MimeTypeMap(".dir","application/x-director"),
            new MimeTypeMap(".dl","video/dl"),
            new MimeTypeMap(".dl","video/x-dl"),
            new MimeTypeMap(".doc","application/msword"),
            new MimeTypeMap(".docx","application/msword"),
            new MimeTypeMap(".dot","application/msword"),
            new MimeTypeMap(".dp","application/commonground"),
            new MimeTypeMap(".drw","application/drafting"),
            new MimeTypeMap(".dump","application/octet-stream"),
            new MimeTypeMap(".dv","video/x-dv"),
            new MimeTypeMap(".dvi","application/x-dvi"),
            new MimeTypeMap(".dwf","model/vnd.dwf"),
            new MimeTypeMap(".dwg","application/acad"),
            new MimeTypeMap(".dwg","image/vnd.dwg"),
            new MimeTypeMap(".dwg","image/x-dwg"),
            new MimeTypeMap(".dxf","application/dxf"),
            new MimeTypeMap(".dxf","image/vnd.dwg"),
            new MimeTypeMap(".dxf","image/x-dwg"),
            new MimeTypeMap(".dxr","application/x-director"),
            new MimeTypeMap(".el","text/x-script.elisp"),
            new MimeTypeMap(".elc","application/x-elc"),
            new MimeTypeMap(".env","application/x-envoy"),
            new MimeTypeMap(".eps","application/postscript"),
            new MimeTypeMap(".es","application/x-esrehber"),
            new MimeTypeMap(".etx","text/x-setext"),
            new MimeTypeMap(".evy","application/envoy"),
            new MimeTypeMap(".evy","application/x-envoy"),
            new MimeTypeMap(".exe","application/octet-stream"),
            new MimeTypeMap(".f","text/plain"),
            new MimeTypeMap(".f","text/x-fortran"),
            new MimeTypeMap(".f77","text/x-fortran"),
            new MimeTypeMap(".f90","text/plain"),
            new MimeTypeMap(".f90","text/x-fortran"),
            new MimeTypeMap(".fdf","application/vnd.fdf"),
            new MimeTypeMap(".fif","application/fractals"),
            new MimeTypeMap(".fif","image/fif"),
            new MimeTypeMap(".fli","video/fli"),
            new MimeTypeMap(".fli","video/x-fli"),
            new MimeTypeMap(".flo","image/florian"),
            new MimeTypeMap(".flx","text/vnd.fmi.flexstor"),
            new MimeTypeMap(".fmf","video/x-atomic3d-feature"),
            new MimeTypeMap(".for","text/plain"),
            new MimeTypeMap(".for","text/x-fortran"),
            new MimeTypeMap(".fpx","image/vnd.fpx"),
            new MimeTypeMap(".fpx","image/vnd.net-fpx"),
            new MimeTypeMap(".frl","application/freeloader"),
            new MimeTypeMap(".funk","audio/make"),
            new MimeTypeMap(".g","text/plain"),
            new MimeTypeMap(".g3","image/g3fax"),
            new MimeTypeMap(".gif","image/gif"),
            new MimeTypeMap(".gl","video/gl"),
            new MimeTypeMap(".gl","video/x-gl"),
            new MimeTypeMap(".gsd","audio/x-gsm"),
            new MimeTypeMap(".gsm","audio/x-gsm"),
            new MimeTypeMap(".gsp","application/x-gsp"),
            new MimeTypeMap(".gss","application/x-gss"),
            new MimeTypeMap(".gtar","application/x-gtar"),
            new MimeTypeMap(".gz","application/x-compressed"),
            new MimeTypeMap(".gz","application/x-gzip"),
            new MimeTypeMap(".gzip","application/x-gzip"),
            new MimeTypeMap(".gzip","multipart/x-gzip"),
            new MimeTypeMap(".h","text/plain"),
            new MimeTypeMap(".h","text/x-h"),
            new MimeTypeMap(".hdf","application/x-hdf"),
            new MimeTypeMap(".help","application/x-helpfile"),
            new MimeTypeMap(".hgl","application/vnd.hp-hpgl"),
            new MimeTypeMap(".hh","text/plain"),
            new MimeTypeMap(".hh","text/x-h"),
            new MimeTypeMap(".hlb","text/x-script"),
            new MimeTypeMap(".hlp","application/hlp"),
            new MimeTypeMap(".hlp","application/x-helpfile"),
            new MimeTypeMap(".hlp","application/x-winhelp"),
            new MimeTypeMap(".hpg","application/vnd.hp-hpgl"),
            new MimeTypeMap(".hpgl","application/vnd.hp-hpgl"),
            new MimeTypeMap(".hqx","application/binhex"),
            new MimeTypeMap(".hqx","application/binhex4"),
            new MimeTypeMap(".hqx","application/mac-binhex"),
            new MimeTypeMap(".hqx","application/mac-binhex40"),
            new MimeTypeMap(".hqx","application/x-binhex40"),
            new MimeTypeMap(".hqx","application/x-mac-binhex40"),
            new MimeTypeMap(".hta","application/hta"),
            new MimeTypeMap(".htc","text/x-component"),
            new MimeTypeMap(".htm","text/html"),
            new MimeTypeMap(".html","text/html"),
            new MimeTypeMap(".htmls","text/html"),
            new MimeTypeMap(".htt","text/webviewhtml"),
            new MimeTypeMap(".ico","image/x-icon"),
            new MimeTypeMap(".idc","text/plain"),
            new MimeTypeMap(".ief","image/ief"),
            new MimeTypeMap(".iefs","image/ief"),
            new MimeTypeMap(".iges","application/iges"),
            new MimeTypeMap(".igs","application/iges"),
            new MimeTypeMap(".igs","model/iges"),
            new MimeTypeMap(".ima","application/x-ima"),
            new MimeTypeMap(".imap","application/x-httpd-imap"),
            new MimeTypeMap(".ins","application/x-internett-signup"),
            new MimeTypeMap(".isu","video/x-isvideo"),
            new MimeTypeMap(".it","audio/it"),
            new MimeTypeMap(".iv","application/x-inventor"),
            new MimeTypeMap(".ivr","i-world/i-vrml"),
            new MimeTypeMap(".ivy","application/x-livescreen"),
            new MimeTypeMap(".jav","text/plain"),
            new MimeTypeMap(".jav","text/x-java-source"),
            new MimeTypeMap(".java","text/plain"),
            new MimeTypeMap(".jfif","image/jpeg"),
            new MimeTypeMap(".jfif","image/pjpeg"),
            new MimeTypeMap(".jfif-tbnl","image/jpeg"),
            new MimeTypeMap(".jpe","image/jpeg"),
            new MimeTypeMap(".jpe","image/pjpeg"),
            new MimeTypeMap(".jpeg","image/jpeg"),
            new MimeTypeMap(".jpeg","image/pjpeg"),
            new MimeTypeMap(".jpg","image/jpeg"),
            new MimeTypeMap(".jps","image/x-jps"),
            new MimeTypeMap(".jut","image/jutvision"),
            new MimeTypeMap(".kar","audio/midi"),
            new MimeTypeMap(".kar","music/x-karaoke"),
            new MimeTypeMap(".ksh","application/x-ksh"),
            new MimeTypeMap(".ksh","text/x-script.ksh"),
            new MimeTypeMap(".lam","audio/x-liveaudio"),
            new MimeTypeMap(".lha","application/lha"),
            new MimeTypeMap(".lha","application/octet-stream"),
            new MimeTypeMap(".lha","application/x-lha"),
            new MimeTypeMap(".lhx","application/octet-stream"),
            new MimeTypeMap(".list","text/plain"),
            new MimeTypeMap(".lma","audio/nspaudio"),
            new MimeTypeMap(".lma","audio/x-nspaudio"),
            new MimeTypeMap(".lsx","text/x-la-asf"),
            new MimeTypeMap(".ltx","application/x-latex"),
            new MimeTypeMap(".lzh","application/octet-stream"),
            new MimeTypeMap(".lzh","application/x-lzh"),
            new MimeTypeMap(".lzx","application/lzx"),
            new MimeTypeMap(".lzx","application/octet-stream"),
            new MimeTypeMap(".lzx","application/x-lzx"),
            new MimeTypeMap(".m","text/plain"),
            new MimeTypeMap(".m","text/x-m"),
            new MimeTypeMap(".m1v","video/mpeg"),
            new MimeTypeMap(".m2a","audio/mpeg"),
            new MimeTypeMap(".m2v","video/mpeg"),
            new MimeTypeMap(".man","application/x-troff-man"),
            new MimeTypeMap(".map","application/x-navimap"),
            new MimeTypeMap(".mar","text/plain"),
            new MimeTypeMap(".mbd","application/mbedlet"),
            new MimeTypeMap(".mc$","application/x-magic-cap-package-1.0"),
            new MimeTypeMap(".mcd","application/mcad"),
            new MimeTypeMap(".mcd","application/x-mathcad"),
            new MimeTypeMap(".mcf","image/vasa"),
            new MimeTypeMap(".mcf","text/mcf"),
            new MimeTypeMap(".mcp","application/netmc"),
            new MimeTypeMap(".mht","message/rfc822"),
            new MimeTypeMap(".mhtml","message/rfc822"),
            new MimeTypeMap(".mid","application/x-midi"),
            new MimeTypeMap(".mid","audio/midi"),
            new MimeTypeMap(".mid","audio/x-mid"),
            new MimeTypeMap(".mid","audio/x-midi"),
            new MimeTypeMap(".mid","music/crescendo"),
            new MimeTypeMap(".mid","x-music/x-midi"),
            new MimeTypeMap(".midi","application/x-midi"),
            new MimeTypeMap(".midi","audio/midi"),
            new MimeTypeMap(".midi","audio/x-mid"),
            new MimeTypeMap(".midi","audio/x-midi"),
            new MimeTypeMap(".midi","music/crescendo"),
            new MimeTypeMap(".midi","x-music/x-midi"),
            new MimeTypeMap(".mif","application/x-frame"),
            new MimeTypeMap(".mif","application/x-mif"),
            new MimeTypeMap(".mjf","audio/x-vnd.audioexplosion.mjuicemediafile"),
            new MimeTypeMap(".mm","application/base64"),
            new MimeTypeMap(".mm","application/x-meme"),
            new MimeTypeMap(".mme","application/base64"),
            new MimeTypeMap(".mod","audio/mod"),
            new MimeTypeMap(".mod","audio/x-mod"),
            new MimeTypeMap(".moov","video/quicktime"),
            new MimeTypeMap(".mov","video/quicktime"),
            new MimeTypeMap(".movie","video/x-sgi-movie"),
            new MimeTypeMap(".mp2","audio/mpeg"),
            new MimeTypeMap(".mp2","audio/x-mpeg"),
            new MimeTypeMap(".mp2","video/mpeg"),
            new MimeTypeMap(".mp2","video/x-mpeg"),
            new MimeTypeMap(".mp2","video/x-mpeq2a"),
            new MimeTypeMap(".mp3","audio/mpeg3"),
            new MimeTypeMap(".mp3","audio/x-mpeg-3"),
            new MimeTypeMap(".mp3","video/mpeg"),
            new MimeTypeMap(".mp3","video/x-mpeg"),
            new MimeTypeMap(".mpa","audio/mpeg"),
            new MimeTypeMap(".mpa","video/mpeg"),
            new MimeTypeMap(".mpc","application/x-project"),
            new MimeTypeMap(".mpe","video/mpeg"),
            new MimeTypeMap(".mpeg","video/mpeg"),
            new MimeTypeMap(".mpg","audio/mpeg"),
            new MimeTypeMap(".mpg","video/mpeg"),
            new MimeTypeMap(".mpga","audio/mpeg"),
            new MimeTypeMap(".mpp","application/vnd.ms-project"),
            new MimeTypeMap(".mpt","application/x-project"),
            new MimeTypeMap(".mpv","application/x-project"),
            new MimeTypeMap(".mpx","application/x-project"),
            new MimeTypeMap(".mrc","application/marc"),
            new MimeTypeMap(".ms","application/x-troff-ms"),
            new MimeTypeMap(".mv","video/x-sgi-movie"),
            new MimeTypeMap(".my","audio/make"),
            new MimeTypeMap(".mzz","application/x-vnd.audioexplosion.mzz"),
            new MimeTypeMap(".nap","image/naplps"),
            new MimeTypeMap(".naplps","image/naplps"),
            new MimeTypeMap(".nc","application/x-netcdf"),
            new MimeTypeMap(".ncm","application/vnd.nokia.configuration-message"),
            new MimeTypeMap(".nif","image/x-niff"),
            new MimeTypeMap(".niff","image/x-niff"),
            new MimeTypeMap(".nix","application/x-mix-transfer"),
            new MimeTypeMap(".nsc","application/x-conference"),
            new MimeTypeMap(".nvd","application/x-navidoc"),
            new MimeTypeMap(".o","application/octet-stream"),
            new MimeTypeMap(".oda","application/oda"),
            new MimeTypeMap(".omc","application/x-omc"),
            new MimeTypeMap(".omcd","application/x-omcdatamaker"),
            new MimeTypeMap(".omcr","application/x-omcregerator"),
            new MimeTypeMap(".p","text/x-pascal"),
            new MimeTypeMap(".p10","application/pkcs10"),
            new MimeTypeMap(".p10","application/x-pkcs10"),
            new MimeTypeMap(".p12","application/pkcs-12"),
            new MimeTypeMap(".p12","application/x-pkcs12"),
            new MimeTypeMap(".p7a","application/x-pkcs7-signature"),
            new MimeTypeMap(".p7c","application/pkcs7-mime"),
            new MimeTypeMap(".p7c","application/x-pkcs7-mime"),
            new MimeTypeMap(".p7m","application/pkcs7-mime"),
            new MimeTypeMap(".p7m","application/x-pkcs7-mime"),
            new MimeTypeMap(".p7r","application/x-pkcs7-certreqresp"),
            new MimeTypeMap(".p7s","application/pkcs7-signature"),
            new MimeTypeMap(".pas","text/pascal"),
            new MimeTypeMap(".pcl","application/vnd.hp-pcl"),
            new MimeTypeMap(".pcl","application/x-pcl"),
            new MimeTypeMap(".pct","image/x-pict"),
            new MimeTypeMap(".pcx","image/x-pcx"),
            new MimeTypeMap(".pdb","chemical/x-pdb"),
            new MimeTypeMap(".pdf","application/pdf"),
            new MimeTypeMap(".pfunk","audio/make"),
            new MimeTypeMap(".pfunk","audio/make.my.funk"),
            new MimeTypeMap(".pgm","image/x-portable-graymap"),
            new MimeTypeMap(".pgm","image/x-portable-greymap"),
            new MimeTypeMap(".pic","image/pict"),
            new MimeTypeMap(".pict","image/pict"),
            new MimeTypeMap(".pkg","application/x-newton-compatible-pkg"),
            new MimeTypeMap(".pko","application/vnd.ms-pki.pko"),
            new MimeTypeMap(".pl","text/plain"),
            new MimeTypeMap(".pl","text/x-script.perl"),
            new MimeTypeMap(".plx","application/x-pixclscript"),
            new MimeTypeMap(".pm","image/x-xpixmap"),
            new MimeTypeMap(".pm","text/x-script.perl-module"),
            new MimeTypeMap(".pm5","application/x-pagemaker"),
            new MimeTypeMap(".png","image/png"),
            new MimeTypeMap(".pnm","application/x-portable-anymap"),
            new MimeTypeMap(".pnm","image/x-portable-anymap"),
            new MimeTypeMap(".pot","application/mspowerpoint"),
            new MimeTypeMap(".pot","application/vnd.ms-powerpoint"),
            new MimeTypeMap(".pov","model/x-pov"),
            new MimeTypeMap(".ppa","application/vnd.ms-powerpoint"),
            new MimeTypeMap(".ppm","image/x-portable-pixmap"),
            new MimeTypeMap(".pps","application/mspowerpoint"),
            new MimeTypeMap(".pps","application/vnd.ms-powerpoint"),
            new MimeTypeMap(".ppt","application/mspowerpoint"),
            new MimeTypeMap(".ppt","application/powerpoint"),
            new MimeTypeMap(".ppt","application/vnd.ms-powerpoint"),
            new MimeTypeMap(".ppt","application/x-mspowerpoint"),
            new MimeTypeMap(".pptx","application/mspowerpoint"),
            new MimeTypeMap(".ppz","application/mspowerpoint"),
            new MimeTypeMap(".pre","application/x-freelance"),
            new MimeTypeMap(".prt","application/pro_eng"),
            new MimeTypeMap(".ps","application/postscript"),
            new MimeTypeMap(".psd","application/octet-stream"),
            new MimeTypeMap(".pvu","paleovu/x-pv"),
            new MimeTypeMap(".qif","image/x-quicktime"),
            new MimeTypeMap(".qt","video/quicktime"),
            new MimeTypeMap(".qtc","video/x-qtc"),
            new MimeTypeMap(".qti","image/x-quicktime"),
            new MimeTypeMap(".qtif","image/x-quicktime"),
            new MimeTypeMap(".ra","audio/x-pn-realaudio"),
            new MimeTypeMap(".ra","audio/x-pn-realaudio-plugin"),
            new MimeTypeMap(".ra","audio/x-realaudio"),
            new MimeTypeMap(".ram","audio/x-pn-realaudio"),
            new MimeTypeMap(".ras","application/x-cmu-raster"),
            new MimeTypeMap(".ras","image/cmu-raster"),
            new MimeTypeMap(".ras","image/x-cmu-raster"),
            new MimeTypeMap(".rast","image/cmu-raster"),
            new MimeTypeMap(".rf","image/vnd.rn-realflash"),
            new MimeTypeMap(".rm","application/vnd.rn-realmedia"),
            new MimeTypeMap(".rm","audio/x-pn-realaudio"),
            new MimeTypeMap(".rmi","audio/mid"),
            new MimeTypeMap(".rmp","audio/x-pn-realaudio"),
            new MimeTypeMap(".rmp","audio/x-pn-realaudio-plugin"),
            new MimeTypeMap(".rng","application/ringing-tones"),
            new MimeTypeMap(".rng","application/vnd.nokia.ringing-tone"),
            new MimeTypeMap(".roff","application/x-troff"),
            new MimeTypeMap(".rpm","audio/x-pn-realaudio-plugin"),
            new MimeTypeMap(".rt","text/richtext"),
            new MimeTypeMap(".rt","text/vnd.rn-realtext"),
            new MimeTypeMap(".rtf","application/rtf"),
            new MimeTypeMap(".rtf","application/x-rtf"),
            new MimeTypeMap(".rtf","text/richtext"),
            new MimeTypeMap(".rtx","application/rtf"),
            new MimeTypeMap(".rtx","text/richtext"),
            new MimeTypeMap(".rv","video/vnd.rn-realvideo"),
            new MimeTypeMap(".s","text/x-asm"),
            new MimeTypeMap(".saveme","application/octet-stream"),
            new MimeTypeMap(".scm","application/x-lotusscreencam"),
            new MimeTypeMap(".scm","text/x-script.guile"),
            new MimeTypeMap(".scm","text/x-script.scheme"),
            new MimeTypeMap(".scm","video/x-scm"),
            new MimeTypeMap(".sdml","text/plain"),
            new MimeTypeMap(".sdr","application/sounder"),
            new MimeTypeMap(".sea","application/sea"),
            new MimeTypeMap(".sea","application/x-sea"),
            new MimeTypeMap(".set","application/set"),
            new MimeTypeMap(".sgml","text/sgml"),
            new MimeTypeMap(".sgml","text/x-sgml"),
            new MimeTypeMap(".sh","application/x-bsh"),
            new MimeTypeMap(".sh","application/x-sh"),
            new MimeTypeMap(".sh","application/x-shar"),
            new MimeTypeMap(".sh","text/x-script.sh"),
            new MimeTypeMap(".shar","application/x-bsh"),
            new MimeTypeMap(".shar","application/x-shar"),
            new MimeTypeMap(".shtml","text/x-server-parsed-html"),
            new MimeTypeMap(".sid","audio/x-psid"),
            new MimeTypeMap(".sit","application/x-sit"),
            new MimeTypeMap(".sit","application/x-stuffit"),
            new MimeTypeMap(".skd","application/x-koan"),
            new MimeTypeMap(".snd","audio/basic"),
            new MimeTypeMap(".snd","audio/x-adpcm"),
            new MimeTypeMap(".sol","application/solids"),
            new MimeTypeMap(".spl","application/futuresplash"),
            new MimeTypeMap(".spr","application/x-sprite"),
            new MimeTypeMap(".src","application/x-wais-source"),
            new MimeTypeMap(".ssi","text/x-server-parsed-html"),
            new MimeTypeMap(".sst","application/vnd.ms-pki.certstore"),
            new MimeTypeMap(".step","application/step"),
            new MimeTypeMap(".stl","application/sla"),
            new MimeTypeMap(".stl","application/vnd.ms-pki.stl"),
            new MimeTypeMap(".stl","application/x-navistyle"),
            new MimeTypeMap(".stp","application/step"),
            new MimeTypeMap(".sv4cpio","application/x-sv4cpio"),
            new MimeTypeMap(".sv4crc","application/x-sv4crc"),
            new MimeTypeMap(".svf","image/vnd.dwg"),
            new MimeTypeMap(".svf","image/x-dwg"),
            new MimeTypeMap(".svr","application/x-world"),
            new MimeTypeMap(".svr","x-world/x-svr"),
            new MimeTypeMap(".swf","application/x-shockwave-flash"),
            new MimeTypeMap(".t","application/x-troff"),
            new MimeTypeMap(".talk","text/x-speech"),
            new MimeTypeMap(".tar","application/x-tar"),
            new MimeTypeMap(".tbk","application/toolbook"),
            new MimeTypeMap(".tbk","application/x-tbook"),
            new MimeTypeMap(".tcl","application/x-tcl"),
            new MimeTypeMap(".tcl","text/x-script.tcl"),
            new MimeTypeMap(".tcsh","text/x-script.tcsh"),
            new MimeTypeMap(".tex","application/x-tex"),
            new MimeTypeMap(".texi","application/x-texinfo"),
            new MimeTypeMap(".texinfo","application/x-texinfo"),
            new MimeTypeMap(".text","application/plain"),
            new MimeTypeMap(".text","text/plain"),
            new MimeTypeMap(".tgz","application/gnutar"),
            new MimeTypeMap(".tgz","application/x-compressed"),
            new MimeTypeMap(".tif","image/tiff"),
            new MimeTypeMap(".tif","image/x-tiff"),
            new MimeTypeMap(".tiff","image/tiff"),
            new MimeTypeMap(".tiff","image/x-tiff"),
            new MimeTypeMap(".tr","application/x-troff"),
            new MimeTypeMap(".tsi","audio/tsp-audio"),
            new MimeTypeMap(".tsp","application/dsptype"),
            new MimeTypeMap(".tsp","audio/tsplayer"),
            new MimeTypeMap(".tsv","text/tab-separated-values"),
            new MimeTypeMap(".turbot","image/florian"),
            new MimeTypeMap(".txt","text/plain"),
            new MimeTypeMap(".uil","text/x-uil"),
            new MimeTypeMap(".uni","text/uri-list"),
            new MimeTypeMap(".unis","text/uri-list"),
            new MimeTypeMap(".unv","application/i-deas"),
            new MimeTypeMap(".uri","text/uri-list"),
            new MimeTypeMap(".uris","text/uri-list"),
            new MimeTypeMap(".ustar","application/x-ustar"),
            new MimeTypeMap(".ustar","multipart/x-ustar"),
            new MimeTypeMap(".uu","application/octet-stream"),
            new MimeTypeMap(".uu","text/x-uuencode"),
            new MimeTypeMap(".uue","text/x-uuencode"),
            new MimeTypeMap(".vcd","application/x-cdlink"),
            new MimeTypeMap(".vcs","text/x-vcalendar"),
            new MimeTypeMap(".vda","application/vda"),
            new MimeTypeMap(".vdo","video/vdo"),
            new MimeTypeMap(".viv","video/vivo"),
            new MimeTypeMap(".viv","video/vnd.vivo"),
            new MimeTypeMap(".vivo","video/vivo"),
            new MimeTypeMap(".vivo","video/vnd.vivo"),
            new MimeTypeMap(".vmf","application/vocaltec-media-file"),
            new MimeTypeMap(".voc","audio/voc"),
            new MimeTypeMap(".voc","audio/x-voc"),
            new MimeTypeMap(".vos","video/vosaic"),
            new MimeTypeMap(".vox","audio/voxware"),
            new MimeTypeMap(".vqe","audio/x-twinvq-plugin"),
            new MimeTypeMap(".vqf","audio/x-twinvq"),
            new MimeTypeMap(".vql","audio/x-twinvq-plugin"),
            new MimeTypeMap(".vrml","application/x-vrml"),
            new MimeTypeMap(".vrml","model/vrml"),
            new MimeTypeMap(".vrml","x-world/x-vrml"),
            new MimeTypeMap(".vrt","x-world/x-vrt"),
            new MimeTypeMap(".vsd","application/x-visio"),
            new MimeTypeMap(".vst","application/x-visio"),
            new MimeTypeMap(".w60","application/wordperfect6.0"),
            new MimeTypeMap(".w61","application/wordperfect6.1"),
            new MimeTypeMap(".w6w","application/msword"),
            new MimeTypeMap(".wav","audio/wav"),
            new MimeTypeMap(".wav","audio/x-wav"),
            new MimeTypeMap(".wb1","application/x-qpro"),
            new MimeTypeMap(".wbmp","image/vnd.wap.wbmp"),
            new MimeTypeMap(".web","application/vnd.xara"),
            new MimeTypeMap(".wiz","application/msword"),
            new MimeTypeMap(".wk1","application/x-123"),
            new MimeTypeMap(".wmf","windows/metafile"),
            new MimeTypeMap(".wml","text/vnd.wap.wml"),
            new MimeTypeMap(".wmls","text/vnd.wap.wmlscript"),
            new MimeTypeMap(".wp","application/wordperfect"),
            new MimeTypeMap(".wp5","application/wordperfect"),
            new MimeTypeMap(".wp5","application/wordperfect6.0"),
            new MimeTypeMap(".wpd","application/wordperfect"),
            new MimeTypeMap(".wpd","application/x-wpwin"),
            new MimeTypeMap(".wq1","application/x-lotus"),
            new MimeTypeMap(".wri","application/mswrite"),
            new MimeTypeMap(".wri","application/x-wri"),
            new MimeTypeMap(".wrl","application/x-world"),
            new MimeTypeMap(".wrl","model/vrml"),
            new MimeTypeMap(".wrl","x-world/x-vrml"),
            new MimeTypeMap(".wrz","model/vrml"),
            new MimeTypeMap(".wrz","x-world/x-vrml"),
            new MimeTypeMap(".wsc","text/scriplet"),
            new MimeTypeMap(".wsrc","application/x-wais-source"),
            new MimeTypeMap(".xbm","image/x-xbitmap"),
            new MimeTypeMap(".xbm","image/x-xbm"),
            new MimeTypeMap(".xbm","image/xbm"),
            new MimeTypeMap(".xdr","video/x-amt-demorun"),
            new MimeTypeMap(".xgz","xgl/drawing"),
            new MimeTypeMap(".xif","image/vnd.xiff"),
            new MimeTypeMap(".xl","application/excel"),
            new MimeTypeMap(".xla","application/excel"),
            new MimeTypeMap(".xla","application/x-excel"),
            new MimeTypeMap(".xla","application/x-msexcel"),
            new MimeTypeMap(".xlb","application/excel"),
            new MimeTypeMap(".xlb","application/vnd.ms-excel"),
            new MimeTypeMap(".xlb","application/x-excel"),
            new MimeTypeMap(".xlc","application/excel"),
            new MimeTypeMap(".xlc","application/vnd.ms-excel"),
            new MimeTypeMap(".xlc","application/x-excel"),
            new MimeTypeMap(".xld","application/excel"),
            new MimeTypeMap(".xld","application/x-excel"),
            new MimeTypeMap(".xlk","application/excel"),
            new MimeTypeMap(".xlk","application/x-excel"),
            new MimeTypeMap(".xll","application/excel"),
            new MimeTypeMap(".xll","application/vnd.ms-excel"),
            new MimeTypeMap(".xll","application/x-excel"),
            new MimeTypeMap(".xlm","application/excel"),
            new MimeTypeMap(".xlm","application/vnd.ms-excel"),
            new MimeTypeMap(".xlm","application/x-excel"),
            new MimeTypeMap(".xls","application/excel"),
            new MimeTypeMap(".xls","application/vnd.ms-excel"),
            new MimeTypeMap(".xls","application/x-excel"),
            new MimeTypeMap(".xls","application/x-msexcel"),
            new MimeTypeMap(".xlsx","application/excel"),
            new MimeTypeMap(".xlt","application/excel"),
            new MimeTypeMap(".xlt","application/x-excel"),
            new MimeTypeMap(".xlv","application/excel"),
            new MimeTypeMap(".xlv","application/x-excel"),
            new MimeTypeMap(".xlw","application/excel"),
            new MimeTypeMap(".xlw","application/vnd.ms-excel"),
            new MimeTypeMap(".xlw","application/x-excel"),
            new MimeTypeMap(".xlw","application/x-msexcel"),
            new MimeTypeMap(".xm","audio/xm"),
            new MimeTypeMap(".xml","application/xml"),
            new MimeTypeMap(".xml","text/xml"),
            new MimeTypeMap(".xmz","xgl/movie"),
            new MimeTypeMap(".xpix","application/x-vnd.ls-xpix"),
            new MimeTypeMap(".xpm","image/x-xpixmap"),
            new MimeTypeMap(".xpm","image/xpm"),
            new MimeTypeMap(".x-png","image/png"),
            new MimeTypeMap(".xsr","video/x-amt-showrun"),
            new MimeTypeMap(".xwd","image/x-xwd"),
            new MimeTypeMap(".xwd","image/x-xwindowdump"),
            new MimeTypeMap(".xyz","chemical/x-pdb"),
            new MimeTypeMap(".z","application/x-compress"),
            new MimeTypeMap(".z","application/x-compressed"),
            new MimeTypeMap(".zip","application/x-compressed"),
            new MimeTypeMap(".zip","application/x-zip-compressed"),
            new MimeTypeMap(".zip","application/zip"),
            new MimeTypeMap(".zip","multipart/x-zip"),
            new MimeTypeMap(".zoo","application/octet-stream"),
            new MimeTypeMap(".zsh","text/x-script.zsh")
        };

    }
}
