﻿var RISE = RISE || {};

RISE.idx = (RISE.idx || 1);
RISE.newIdx = (RISE.newIdx || function(){
	RISE.idx++;
	return RISE.idx;
});

RISE.DatePickerCtrl = function(domEl, config) {
	this.idx = RISE.newIdx();
	this.domEl = ((typeof(domEl) == "string") ? document.getElementById(domEl) : domEl);
	this.onChange = ((config && config["onChange"]) ? config["onChange"] : null);
	this.onChangeContext = ((config && config["onChangeContext"]) ? config["onChangeContext"] : null);
	this.textBox = ((config && config["textBox"]) ? config["textBox"] : { value: "", style: "width: 120px;", focus: false });
	this.image = ((config && config["image"]) ? config["image"] : { src: "", alt: "", title: "", style: "", width: "16px", height: "16px" });
	this.pickerConfig = ((config && config["pickerConfig"]) ? config["pickerConfig"] : {});
	this.markupIds = {
		textBox: this.fldToID("textBox"), 
		image: this.fldToID("image"), 
		datePicker: this.fldToID("datePicker")
	};
	this.pickerConfig["selectCallback"] = this._onSelect;
	this.pickerConfig["selectCallbackContext"] = this;
	this.pickerConfig["closeCallback"] = this._hidePanel;
	this.pickerConfig["closeCallbackContext"] = this;

	this.dateToString = ((config && config["dateToString"]) ? config["dateToString"] : this.dateToString);
	this.stringToDate = ((config && config["stringToDate"]) ? config["stringToDate"] : this.stringToDate);
};

RISE.DatePickerCtrl.prototype = {
	prefix: "riseDatePickerCtrl", 
	fldToID: function(fld) {
		var s = [];
		s[s.length] = this.prefix;
		s[s.length] = this.idx.toString();
		s[s.length] = '_';
		s[s.length] = fld;
		return s.join('');
	}, 
	idToFld: function(id) {
		var s = id.split('_');
		return ((s.length == 2) ? s[1] : null);
	}, 
	htmlEncode: function(s){
		if (s && typeof(s) == "string") {
			return s.replace(/\"/g, "&quot;").replace(/</g, "&lt;").replace(/>/g, "&gt;");
		} 
		return s;
	}, 
	dateToString: function(date){
		try{
			if(date) {
				var pad = function (val) {
					val = val.toString();
					while (val.length < 2) val = "0" + val;
					return val;
				};
				return (date ? date.getFullYear() + '-' + pad((date.getMonth()+1)) + '-' + pad(date.getDate()) + ((date.getHours() != 0 || date.getMinutes() != 0 || date.getSeconds() != 0) ? ' ' + pad(date.getHours()) + ':' + pad(date.getMinutes()) + ':' + pad(date.getSeconds()) : "") : null);
			}
		} catch(ex) {}
		return null;
	},
	stringToDate: function(datestring){
		try{
			if(datestring) {
				if(datestring == "d" || datestring == "D"){
					var now = new Date();
					return new Date(now.getFullYear(), now.getMonth(), now.getDate(), 0, 0, 0);
				}
				if(datestring == "t" || datestring == "T"){
					return new Date();
				}
				if(!isNaN(datestring)){
					var now = new Date();
					var rc = new Date(now.getFullYear(), now.getMonth(), now.getDate(), 0, 0, 0);
					if(datestring.substring(0,1) == "-" || datestring.substring(0,1) == "+") 
						rc.setTime(rc.getTime() + (24*3600*1000*parseInt(datestring,10)));
					else rc.setDate(parseInt(datestring,10));
					return rc;
				}
				var num = function(val, fb) {
					return (val && val!='' ? parseInt(val,10) : (fb ? fb : 0));
				};
				var m = datestring.match(/^\s*((\d\d\d\d)-(\d\d)-(\d\d))((\s|T)(\d\d)(:(\d\d)(:(\d\d))?)?)?\s*$/i);
				return new Date(num(m[2]), num(m[3])-1, num(m[4]), num(m[7]), num(m[9]), num(m[11]));
			}
		} catch(ex) {}
		return null;
	}, 
	pos: function (obj) {
		try {
			if (obj && obj.offsetParent) {
				var curleft = curtop = 0;
				do {
					curleft += obj.offsetLeft;
					curtop += obj.offsetTop;
				} while (obj = obj.offsetParent);
				return { x: curleft, y: curtop };
			}
		} catch (ex) {}
		return  null;
	}, 
	_onSelect: function(date){
		var textBoxEl = document.getElementById(this.markupIds["textBox"]);
		textBoxEl.value = this.dateToString(date) || "";
		
		if(this.onChange) {
			if(this.onChangeContext) this.onChange.call(this.onChangeContext, textBoxEl, date);
			else this.onChange(textBoxEl, date);
		}
		try {
			textBoxEl.focus();
		} catch(ex) {}
		var datePickerEl = document.getElementById(this.markupIds["datePicker"]);
		if(datePickerEl){
			datePickerEl.style.display = "none";
		}
	}, 
	_hidePanel: function() {
		var datePickerEl = document.getElementById(this.markupIds["datePicker"]);
		if(datePickerEl){
			datePickerEl.style.display = "none";
		}
	}, 
	_displayPanel: function(textBoxEl, imageEl, datePickerEl) {
		if(datePickerEl) {
			if(datePickerEl.style.display == "block")
				datePickerEl.style.display = "none";
			else {
				this.pickerConfig["date"] = this.stringToDate(textBoxEl.value);
				new RISE.DatePicker(datePickerEl, this.pickerConfig).render();
				datePickerEl.style.display = "block";
			}
		}
	}, 
	render: function() {
		if(this.domEl) {
			var self = this;
			var html = [];
			html[html.length] = '<div>';
			html[html.length] = '    <table cellpadding="0" cellspacing="0">';
			html[html.length] = '        <tr>';
			html[html.length] = '            <td>';
			html[html.length] = '                <input id="' + this.markupIds["textBox"] + '" type="text" style="' + ((this.textBox && this.textBox["style"]) ? this.textBox["style"] : "") + '" value="' + ((this.textBox && this.textBox["value"]) ? this.htmlEncode(this.textBox["value"]) : "") + '" />';
			html[html.length] = '            </td>';
			html[html.length] = '            <td>&nbsp;</td>';
			html[html.length] = '            <td>';
			html[html.length] = '                <img id="' + this.markupIds["image"] + '" style="' + ((this.image && this.image["style"]) ? this.image["style"] : "") + '" src="' + ((this.image && this.image["src"]) ? this.image["src"] : "") + '" alt="' + ((this.image && this.image["alt"]) ? this.image["alt"] : "") + '" title="' + ((this.image && this.image["title"]) ? this.image["title"] : "") + '" width="' + ((this.image && this.image["width"]) ? this.image["width"] : "") + '" height="' + ((this.image && this.image["height"]) ? this.image["height"] : "") + '" />';
			html[html.length] = '            </td>';
			html[html.length] = '        </tr>';
			html[html.length] = '        <tr>';
			html[html.length] = '            <td colspan="3">';
			html[html.length] = '                <div id="' + this.markupIds["datePicker"] + '" style="position: absolute; display:none; width: 180px;"></div>'
			html[html.length] = '            </td>';
			html[html.length] = '        </tr>';
			html[html.length] = '    </table>';
			html[html.length] = '</div>';
			this.domEl.innerHTML = html.join('');
			var textBoxEl = document.getElementById(this.markupIds["textBox"]);
			var imageEl = document.getElementById(this.markupIds["image"]);
			var datePickerEl = document.getElementById(this.markupIds["datePicker"]);
			if(textBoxEl && imageEl && datePickerEl) {
				if(this.textBox && this.textBox["focus"]){
					try{ textBoxEl.focus(); } catch(ex) {}
				}
				imageEl.onclick = function () {
					self._displayPanel(textBoxEl, imageEl, datePickerEl);
				};
				textBoxEl.onblur = function () {
					datePickerEl.style.display = "none";
					var date = self.stringToDate(textBoxEl.value);
					textBoxEl.value = ((date) ? self.dateToString(date) : "");
					if(self.onChange) {
						if(self.onChangeContext) self.onChange.call(self.onChangeContext, textBoxEl, date);
						else self.onChange(textBoxEl, date);
					}
				};
				textBoxEl.onkeyup = function() {
					datePickerEl.style.display = "none";
				};
			}
		}
	}, 
	destroy: function() {
		if(this.domEl) {
			this.domEl.innerHTML = "";
		}
	}
};
