﻿var DragTreeNode = {
	markupIDs: {
		evContainer: "dragDropEventContainer", 
		dragContainer: "dragDropContainer", 
		dragEl: "dragDropEl"
	}, 
	oSiteTree: null, 
	moveCallback: null, 
	moveContext: null, 
	tnPattern: /^ygtv[0-9]+$/, 
	idPattern: /id=\w*/ig, 
	delta: {
		x: -10,
		y: -10
	}, 
	drgEl: null,
	srcEl: null, 
	dstEl: null,
	drgTres: {
		pending: true, 
		treshold: 3, 
		startX: 0, 
		startY: 0
	}, 
	nodeExpander: {
		timer: null, 
		node: null, 
		timeout: 400
	}, 
	
	init: function(siteTree, evContainer, dragContainer, moveCallback, moveContext){
		DragTreeNode.oSiteTree = siteTree;
		DragTreeNode.moveCallback = moveCallback;
		DragTreeNode.moveContext = moveContext;
		DragTreeNode.markupIDs["evContainer"] = evContainer;
		DragTreeNode.markupIDs["dragContainer"] = dragContainer;
		YAHOO.util.Event.on(DragTreeNode.markupIDs["evContainer"], 'mousedown', DragTreeNode.onMouseDown);
		YAHOO.util.Event.on(DragTreeNode.markupIDs["evContainer"], 'mousemove', DragTreeNode.onMouseMove);
		YAHOO.util.Event.on(DragTreeNode.markupIDs["evContainer"], 'mouseup', DragTreeNode.onMouseUp);
	}, 
	onMouseDown: function(ev) {
		try{
			DragTreeNode._reset();
			if(DragTreeNode._leftButtonPressed(ev)) {
				var srcEl = DragTreeNode._getNodeEl(YAHOO.util.Event.getTarget(ev));
				if(srcEl){
					var srcNode = DragTreeNode.oSiteTree.getNodeByElement(srcEl);
					if(srcNode && !srcNode._isNotDraggable){
						if(DragTreeNode._createDragEl(srcEl)){
							DragTreeNode.srcEl = srcEl;
							DragTreeNode.drgTres.pending = true;
							DragTreeNode.drgTres.startX = DragTreeNode._evX(ev);
							DragTreeNode.drgTres.startY = DragTreeNode._evY(ev);

							if(typeof(document.onselectstart) !== "undefined") {
								document.onselectstart = DragTreeNode._preventSelectStart;
							} else {
								YAHOO.util.Event.preventDefault(ev);
							}
						} else {
							DragTreeNode._reset();
						}
					}
				}
			}
		} catch(ex) {
			DragTreeNode._reset();
		}
	}, 
	onMouseMove: function(ev) {
		try{
			if(DragTreeNode.drgEl && DragTreeNode._leftButtonPressed(ev)){
				DragTreeNode._moveDragEl(ev);
				var dstNode = DragTreeNode.oSiteTree.getNodeByElement(DragTreeNode._getNodeEl(YAHOO.util.Event.getTarget(ev)));
				DragTreeNode._expandPrepare(dstNode);
				YAHOO.util.Event.stopEvent(ev);
			} else {
				DragTreeNode._reset();
			}
		} catch(ex) {
			DragTreeNode._reset();
		}
	}, 
	onMouseUp: function(ev) {
		try{
			//YAHOO.util.Event.stopEvent(ev);
			if(DragTreeNode.oSiteTree && DragTreeNode.srcEl && DragTreeNode.drgEl) {
				DragTreeNode.dstEl = DragTreeNode._getNodeEl(YAHOO.util.Event.getTarget(ev));
				var srcNode = DragTreeNode.oSiteTree.getNodeByElement(DragTreeNode.srcEl);
				var dstNode = DragTreeNode.oSiteTree.getNodeByElement(DragTreeNode.dstEl);
				
				if(DragTreeNode._isAllowedDrop(srcNode, dstNode)){
					if (DragTreeNode.moveCallback) {
						if(DragTreeNode.moveContext) DragTreeNode.moveCallback.call(DragTreeNode.moveContext, dstNode, srcNode);
						else DragTreeNode.moveCallback(dstNode, srcNode);
					}
				}
			}
		} catch(ex) {
		}
		DragTreeNode._reset();
	}, 
	_pressedButton: function(ev){
		try{
			if (ev.which)
				return (ev.which < 2) ? ((ev.which == 1) ? "LEFT" : "") : ((ev.which == 2) ? "MIDDLE" : "RIGHT");
			else if (ev.button)
				return (ev.button < 2) ? ((ev.button == 1) ? "LEFT" : "") : ((ev.button == 4) ? "MIDDLE" : "RIGHT");
			} catch(ex) {
		}
		return "";
	}, 
	_leftButtonPressed: function(ev) {
		return (DragTreeNode._pressedButton(ev) == "LEFT");
	}, 
	_rightButtonPressed: function(ev){
		return (DragTreeNode._pressedButton(ev) == "RIGHT");
	}, 
	_middleButtonPressed: function(ev){
		return (DragTreeNode._pressedButton(ev) == "MIDDLE");
	}, 
	_preventSelectStart: function(){
		return (DragTreeNode.drgEl ? false : true);
	}, 
	_isAllowedDrop: function(srcNode, dstNode){
		if(!(srcNode && dstNode))
			return false;
		if(srcNode === dstNode)
			return false;
		while(dstNode.parent){
			if(dstNode.parent === srcNode)
				return false;
			dstNode = dstNode.parent;
		}
		return true;
	}, 	
	_getNodeEl: function(el){
		var nodeEl = null;
		if(el) {
			if(el.id && el.id.match(DragTreeNode.tnPattern))
				nodeEl = el;
			else {
				YAHOO.util.Dom.getAncestorBy(el, function(n) {
					if (n.id && n.id.match(DragTreeNode.tnPattern)) {
						nodeEl = n;
						return true;
					}
					return false;
				});
			}
		}
		return nodeEl;
	}, 
	_reset: function(el){
		DragTreeNode.srcEl = null;
		DragTreeNode.dstEl = null;
		if(DragTreeNode.drgEl){
			document.getElementById(DragTreeNode.markupIDs["dragContainer"]).innerHTML = "";
			DragTreeNode.drgEl = null;
		}
		DragTreeNode.drgTres.pending = true;
		DragTreeNode._expandReset();
	}, 
	_createDragEl: function(el){
		if(el){
			document.getElementById(DragTreeNode.markupIDs["dragContainer"]).innerHTML = "<div id=\"" + DragTreeNode.markupIDs["dragEl"] + "\" style=\"position:absolute; z-index: 999999; display:none; background-color: rgba(192, 192, 192, 0.67);\"</div>";
			DragTreeNode.drgEl = document.getElementById(DragTreeNode.markupIDs["dragEl"]);
			DragTreeNode.drgEl.innerHTML = el.innerHTML.replace(DragTreeNode.idPattern ,'');
			YAHOO.util.Dom.setStyle(DragTreeNode.drgEl, "border", "2px solid gray");
		}
		return DragTreeNode.drgEl;
	}, 
	_evX: function(ev){
		return (ev.x ? ev.x : (ev.pageX ? ev.pageX : -1));
	}, 
	_evY: function(ev){
		return (ev.y ? ev.y : (ev.pageY ? ev.pageY : -1));
	}, 
	_moveDragEl: function(ev){
		if(DragTreeNode.drgEl && ev && (ev.x || ev.pageX) && (ev.y || ev.pageY)) {
			try{
				var x = DragTreeNode._evX(ev);
				var y = DragTreeNode._evY(ev);
				if(x != -1 && y != -1){
					if(DragTreeNode.drgTres.pending){
						if(Math.abs(DragTreeNode.drgTres.startX - x) > DragTreeNode.drgTres.treshold || Math.abs(DragTreeNode.drgTres.startY - y) > DragTreeNode.drgTres.treshold){
							DragTreeNode.drgTres.pending = false;
							DragTreeNode.drgEl.style.display = "block";
						}
					}
					if(!DragTreeNode.drgTres.pending){
						x = x - YAHOO.util.Dom.getX(DragTreeNode.markupIDs["evContainer"]) - DragTreeNode.delta.x;
						y = y - YAHOO.util.Dom.getY(DragTreeNode.markupIDs["evContainer"]) - DragTreeNode.delta.y;
						YAHOO.util.Dom.setStyle(DragTreeNode.drgEl, "top", y + "px");
						YAHOO.util.Dom.setStyle(DragTreeNode.drgEl, "left", x + "px");
					}
				}
			} catch(ex){
				alert(ex);
			}
		}
	}, 
	_expandReset: function(){
		if(DragTreeNode.nodeExpander.timer){
			clearTimeout(DragTreeNode.nodeExpander.timer);
		}
		DragTreeNode.nodeExpander.timer = null;
		DragTreeNode.nodeExpander.node = null;
	}, 
	_expandPrepare: function(node){
		if(node){
			if(node !== DragTreeNode.nodeExpander.node){
				DragTreeNode._expandReset();
				if(!node.expanded && node.children.length > 0){
					DragTreeNode.nodeExpander.timer = setTimeout("DragTreeNode._expandExecute()", DragTreeNode.nodeExpander.timeout);
					DragTreeNode.nodeExpander.node = node;
				}
			}
		} else {
			DragTreeNode._expandReset();
		}
	}, 
	_expandExecute: function(){
		if(DragTreeNode.nodeExpander.node && !DragTreeNode.nodeExpander.node.expanded && DragTreeNode.nodeExpander.node.children.length > 0)
			DragTreeNode.nodeExpander.node.expand();
		DragTreeNode.nodeExpander.timer = null;
		DragTreeNode.nodeExpander.node = null;
	}	
}
