﻿var IEdit = {

    wsuri: "cms.WS.IEdit.asmx",        // You must enter the correct uri to your installed web service.
    wsenvironment: ".NET",               // Possible values are: null, ".NET", "PHP"

    /****************************************************************
        --- FUNCTION INDEX ---

        DeleteContent
        Download
        DownloadThumbnail
        GetContentDetails
        ListChildContent
        ListRootContent
        ListSiteArticleHints
        ListSiteContent
        ListSites
        LookupIDFromFriendlyName
        MoveContent
        SaveArticle
        SaveArticleText
        SaveDocument
        SaveImage
        SaveLink
        SaveMessage
        SaveNone
        SearchByArticleText
        SearchByLinkTargetURI
        SearchByTitleType
        SearchImageByTitle
        Upload

    ****************************************************************/

    /*
        // Description: Delete content, e.g. an article, a document.
        // This code exemplifies how to call the generated function DeleteContent
        IEdit.DeleteContent(
            {"ticket": your_string_or_null, "ContentID": your_int},
            function(args){
                // This function is called on success
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    DeleteContent: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/DeleteContent",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": args["ContentID"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Download image or document file content
        // This code exemplifies how to call the generated function Download
        IEdit.Download(
            {"ticket": your_string_or_null, "contentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: Title (string), MimeType (string), bytes (blob)
                // Example:
                var yourVariable1 = result["Title"]; 
                var yourVariable2 = result["MimeType"]; 
                var yourVariable3 = result["bytes"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    Download: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/Download",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "contentID": (typeof(args["contentID"]) !== 'undefined' ? args["contentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Download image thumbnail file content
        // This code exemplifies how to call the generated function DownloadThumbnail
        IEdit.DownloadThumbnail(
            {"ticket": your_string_or_null, "contentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: MimeType (string), imageBytes (blob)
                // Example:
                var yourVariable1 = result["MimeType"]; 
                var yourVariable2 = result["imageBytes"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    DownloadThumbnail: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/DownloadThumbnail",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "contentID": (typeof(args["contentID"]) !== 'undefined' ? args["contentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Get content details for any kind of content
        // This code exemplifies how to call the generated function GetContentDetails
        IEdit.GetContentDetails(
            {"ticket": your_string_or_null, "ContentID": your_int},
            function(result, args){
                // This function is called on success
                // result contains: ContentID (int), ContentSUID (string), ContentType (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), EditedDate (datetime), EditedBy (string), SiteID (int), SiteName (string), ParentID (int_or_null), friendlyName (string), hasArticle (bool), ArticleID (int), ArticleEditor (string_or_null), ArticleData (text_or_null), ArticleHint (string_or_null), hasDocument (bool), DocumentID (int), DocumentMimeType (string), hasImage (bool), ImageID (int), ImageMimeType (string), ImageWidth (int), ImageHeight (int), ImageAlternative (string_or_null), hasLink (bool), LinkID (int), LinkTargetURI (string_or_null), LinkTargetURL (string_or_null), hasMessage (bool), MessageID (int), MessageSource (string_or_null), MessageData (text_or_null)
                // Example:
                var yourVariable1 = result["ContentID"]; 
                var yourVariable2 = result["ContentSUID"]; 
                var yourVariable3 = result["ContentType"]; 
                var yourVariable4 = result["ContentTitle"]; 
                var yourVariable5 = result["ContentPublished"]; 
                var yourVariable6 = result["ContentSortOrder"]; 
                var yourVariable7 = result["ContentKeywords"]; 
                var yourVariable8 = result["ContentDescription"]; 
                var yourVariable9 = result["ContentRobots"]; 
                var yourVariable10 = result["ContentLanguage"]; 
                var yourVariable11 = result["ContentCustom"]; 
                var yourVariable12 = result["ContentAllowMessages"]; 
                var yourVariable13 = result["ContentAbstract"]; 
                var yourVariable14 = result["EditedDate"]; 
                var yourVariable15 = result["EditedBy"]; 
                var yourVariable16 = result["SiteID"]; 
                var yourVariable17 = result["SiteName"]; 
                var yourVariable18 = result["ParentID"]; 
                var yourVariable19 = result["friendlyName"]; 
                var yourVariable20 = result["hasArticle"]; 
                var yourVariable21 = result["ArticleID"]; 
                var yourVariable22 = result["ArticleEditor"]; 
                var yourVariable23 = result["ArticleData"]; 
                var yourVariable24 = result["ArticleHint"]; 
                var yourVariable25 = result["hasDocument"]; 
                var yourVariable26 = result["DocumentID"]; 
                var yourVariable27 = result["DocumentMimeType"]; 
                var yourVariable28 = result["hasImage"]; 
                var yourVariable29 = result["ImageID"]; 
                var yourVariable30 = result["ImageMimeType"]; 
                var yourVariable31 = result["ImageWidth"]; 
                var yourVariable32 = result["ImageHeight"]; 
                var yourVariable33 = result["ImageAlternative"]; 
                var yourVariable34 = result["hasLink"]; 
                var yourVariable35 = result["LinkID"]; 
                var yourVariable36 = result["LinkTargetURI"]; 
                var yourVariable37 = result["LinkTargetURL"]; 
                var yourVariable38 = result["hasMessage"]; 
                var yourVariable39 = result["MessageID"]; 
                var yourVariable40 = result["MessageSource"]; 
                var yourVariable41 = result["MessageData"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    GetContentDetails: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/GetContentDetails",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": args["ContentID"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    result["EditedDate"] = IEdit.JSONHelper.StringToDate(result["EditedDate"]);
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all sub-content of specified content.
        // This code exemplifies how to call the generated function ListChildContent
        IEdit.ListChildContent(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "ContentID": your_int_or_null},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), ParentID (int_or_null), ContentType (string), friendlyName (string)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentTitle"]; 
                    var yourVariable4 = results[i]["ContentPublished"]; 
                    var yourVariable5 = results[i]["ContentSortOrder"]; 
                    var yourVariable6 = results[i]["ContentKeywords"]; 
                    var yourVariable7 = results[i]["ContentDescription"]; 
                    var yourVariable8 = results[i]["ContentRobots"]; 
                    var yourVariable9 = results[i]["ContentLanguage"]; 
                    var yourVariable10 = results[i]["ContentCustom"]; 
                    var yourVariable11 = results[i]["ContentAllowMessages"]; 
                    var yourVariable12 = results[i]["ContentAbstract"]; 
                    var yourVariable13 = results[i]["SiteID"]; 
                    var yourVariable14 = results[i]["ParentID"]; 
                    var yourVariable15 = results[i]["ContentType"]; 
                    var yourVariable16 = results[i]["friendlyName"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    ListChildContent: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/ListChildContent",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all root-level content in a site
        // This code exemplifies how to call the generated function ListRootContent
        IEdit.ListRootContent(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "siteID": your_int},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentType (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), ParentID (int_or_null), friendlyName (string)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentType"]; 
                    var yourVariable4 = results[i]["ContentTitle"]; 
                    var yourVariable5 = results[i]["ContentPublished"]; 
                    var yourVariable6 = results[i]["ContentSortOrder"]; 
                    var yourVariable7 = results[i]["ContentKeywords"]; 
                    var yourVariable8 = results[i]["ContentDescription"]; 
                    var yourVariable9 = results[i]["ContentRobots"]; 
                    var yourVariable10 = results[i]["ContentLanguage"]; 
                    var yourVariable11 = results[i]["ContentCustom"]; 
                    var yourVariable12 = results[i]["ContentAllowMessages"]; 
                    var yourVariable13 = results[i]["ContentAbstract"]; 
                    var yourVariable14 = results[i]["SiteID"]; 
                    var yourVariable15 = results[i]["ParentID"]; 
                    var yourVariable16 = results[i]["friendlyName"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    ListRootContent: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/ListRootContent",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "siteID": args["siteID"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists the site hint list.
        // This code exemplifies how to call the generated function ListSiteArticleHints
        IEdit.ListSiteArticleHints(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "siteID": your_int},
            function(results, args){
                // This function is called on success
                // results contains: ArticleHintID (int), ArticleHintName (string), SiteID (int)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ArticleHintID"]; 
                    var yourVariable2 = results[i]["ArticleHintName"]; 
                    var yourVariable3 = results[i]["SiteID"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    ListSiteArticleHints: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/ListSiteArticleHints",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "siteID": args["siteID"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all content in a site.
        // This code exemplifies how to call the generated function ListSiteContent
        IEdit.ListSiteContent(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "SiteID": your_int},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentType (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), ParentID (int_or_null), friendlyName (string)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentType"]; 
                    var yourVariable4 = results[i]["ContentTitle"]; 
                    var yourVariable5 = results[i]["ContentPublished"]; 
                    var yourVariable6 = results[i]["ContentSortOrder"]; 
                    var yourVariable7 = results[i]["ContentKeywords"]; 
                    var yourVariable8 = results[i]["ContentDescription"]; 
                    var yourVariable9 = results[i]["ContentRobots"]; 
                    var yourVariable10 = results[i]["ContentLanguage"]; 
                    var yourVariable11 = results[i]["ContentCustom"]; 
                    var yourVariable12 = results[i]["ContentAllowMessages"]; 
                    var yourVariable13 = results[i]["ContentAbstract"]; 
                    var yourVariable14 = results[i]["SiteID"]; 
                    var yourVariable15 = results[i]["ParentID"]; 
                    var yourVariable16 = results[i]["friendlyName"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    ListSiteContent: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/ListSiteContent",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "SiteID": args["SiteID"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all sites you're allowed to edit.
        // This code exemplifies how to call the generated function ListSites
        IEdit.ListSites(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null},
            function(results, args){
                // This function is called on success
                // results contains: SiteID (int), SiteName (string), SiteMembersOnly (bool), SiteRecycleBin (bool)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["SiteID"]; 
                    var yourVariable2 = results[i]["SiteName"]; 
                    var yourVariable3 = results[i]["SiteMembersOnly"]; 
                    var yourVariable4 = results[i]["SiteRecycleBin"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    ListSites: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/ListSites",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // This code exemplifies how to call the generated function LookupIDFromFriendlyName
        IEdit.LookupIDFromFriendlyName(
            {"ticket": your_string_or_null, "friendlyName": your_string_or_null},
            function(result, args){
                // This function is called on success
                // result contains: ContentID (int)
                // Example:
                var yourVariable1 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    LookupIDFromFriendlyName: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/LookupIDFromFriendlyName",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "friendlyName": (typeof(args["friendlyName"]) !== 'undefined' ? args["friendlyName"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Move content in the content structure.
        // This code exemplifies how to call the generated function MoveContent
        IEdit.MoveContent(
            {"ticket": your_string_or_null, "ContentID": your_int, "newParentID": your_int_or_null, "newSiteID": your_int, "newSortOrder": your_string_or_null},
            function(args){
                // This function is called on success
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    MoveContent: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/MoveContent",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": args["ContentID"], "newParentID": (typeof(args["newParentID"]) !== 'undefined' ? args["newParentID"] : null), "newSiteID": args["newSiteID"], "newSortOrder": (typeof(args["newSortOrder"]) !== 'undefined' ? args["newSortOrder"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or updates article content
        // This code exemplifies how to call the generated function SaveArticle
        IEdit.SaveArticle(
            {"ticket": your_string_or_null, "ArticleID": your_int_or_null, "ArticleEditor": your_string_or_null, "ArticleData": your_text_or_null, "ArticleHint": your_string_or_null, "ContentID": your_int_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null, "ContentSUID": your_string_or_null},
            function(result, args){
                // This function is called on success
                // result contains: ArticleID (int), ContentID (int)
                // Example:
                var yourVariable1 = result["ArticleID"]; 
                var yourVariable2 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveArticle: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveArticle",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ArticleID": (typeof(args["ArticleID"]) !== 'undefined' ? args["ArticleID"] : null), "ArticleEditor": (typeof(args["ArticleEditor"]) !== 'undefined' ? args["ArticleEditor"] : null), "ArticleData": (typeof(args["ArticleData"]) !== 'undefined' ? args["ArticleData"] : null), "ArticleHint": (typeof(args["ArticleHint"]) !== 'undefined' ? args["ArticleHint"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Updates the article text body.
        // This code exemplifies how to call the generated function SaveArticleText
        IEdit.SaveArticleText(
            {"ticket": your_string_or_null, "ContentID": your_int, "ArticleData": your_text_or_null, "ContentSUID": your_string_or_null},
            function(args){
                // This function is called on success
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveArticleText: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveArticleText",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": args["ContentID"], "ArticleData": (typeof(args["ArticleData"]) !== 'undefined' ? args["ArticleData"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or updates document content excl the document file
        // This code exemplifies how to call the generated function SaveDocument
        IEdit.SaveDocument(
            {"ticket": your_string_or_null, "DocumentID": your_int_or_null, "DocumentMimeType": your_string, "ContentID": your_int_or_null, "ContentSUID": your_string_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: DocumentID (int), ContentID (int)
                // Example:
                var yourVariable1 = result["DocumentID"]; 
                var yourVariable2 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveDocument: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveDocument",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "DocumentID": (typeof(args["DocumentID"]) !== 'undefined' ? args["DocumentID"] : null), "DocumentMimeType": args["DocumentMimeType"], "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or updates image content excl the image file
        // This code exemplifies how to call the generated function SaveImage
        IEdit.SaveImage(
            {"ticket": your_string_or_null, "ImageID": your_int_or_null, "ImageMimeType": your_string, "ImageWidth": your_int, "ImageHeight": your_int, "ImageAlternative": your_string_or_null, "ContentID": your_int_or_null, "ContentSUID": your_string_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: ImageID (int), ContentID (int)
                // Example:
                var yourVariable1 = result["ImageID"]; 
                var yourVariable2 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveImage: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveImage",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ImageID": (typeof(args["ImageID"]) !== 'undefined' ? args["ImageID"] : null), "ImageMimeType": args["ImageMimeType"], "ImageWidth": args["ImageWidth"], "ImageHeight": args["ImageHeight"], "ImageAlternative": (typeof(args["ImageAlternative"]) !== 'undefined' ? args["ImageAlternative"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or update link content.
        // This code exemplifies how to call the generated function SaveLink
        IEdit.SaveLink(
            {"ticket": your_string_or_null, "LinkID": your_int_or_null, "ContentID": your_int_or_null, "ContentSUID": your_string_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null, "LinkTargetURI": your_string_or_null, "LinkTargetURL": your_string_or_null},
            function(result, args){
                // This function is called on success
                // result contains: LinkID (int), ContentID (int)
                // Example:
                var yourVariable1 = result["LinkID"]; 
                var yourVariable2 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveLink: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveLink",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "LinkID": (typeof(args["LinkID"]) !== 'undefined' ? args["LinkID"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null), "LinkTargetURI": (typeof(args["LinkTargetURI"]) !== 'undefined' ? args["LinkTargetURI"] : null), "LinkTargetURL": (typeof(args["LinkTargetURL"]) !== 'undefined' ? args["LinkTargetURL"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or update message content
        // This code exemplifies how to call the generated function SaveMessage
        IEdit.SaveMessage(
            {"ticket": your_string_or_null, "MessageID": your_int_or_null, "MessageSource": your_string_or_null, "MessageData": your_text_or_null, "ContentID": your_int_or_null, "ContentSUID": your_string_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: MessageID (int), ContentID (int)
                // Example:
                var yourVariable1 = result["MessageID"]; 
                var yourVariable2 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveMessage: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveMessage",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "MessageID": (typeof(args["MessageID"]) !== 'undefined' ? args["MessageID"] : null), "MessageSource": (typeof(args["MessageSource"]) !== 'undefined' ? args["MessageSource"] : null), "MessageData": (typeof(args["MessageData"]) !== 'undefined' ? args["MessageData"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Creates or updates unspecified content, i.e. a folder.
        // This code exemplifies how to call the generated function SaveNone
        IEdit.SaveNone(
            {"ticket": your_string_or_null, "ContentID": your_int_or_null, "ContentSUID": your_string_or_null, "ContentTitle": your_string, "ContentSortOrder": your_string_or_null, "SiteID": your_int, "ContentPublished": your_bool, "ContentKeywords": your_string_or_null, "ContentDescription": your_string_or_null, "ContentRobots": your_string_or_null, "ContentLanguage": your_string_or_null, "ContentCustom": your_string_or_null, "ContentAllowMessages": your_bool, "ContentAbstract": your_text_or_null, "ParentID": your_int_or_null},
            function(result, args){
                // This function is called on success
                // result contains: ContentID (int)
                // Example:
                var yourVariable1 = result["ContentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SaveNone: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SaveNone",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "ContentID": (typeof(args["ContentID"]) !== 'undefined' ? args["ContentID"] : null), "ContentSUID": (typeof(args["ContentSUID"]) !== 'undefined' ? args["ContentSUID"] : null), "ContentTitle": args["ContentTitle"], "ContentSortOrder": (typeof(args["ContentSortOrder"]) !== 'undefined' ? args["ContentSortOrder"] : null), "SiteID": args["SiteID"], "ContentPublished": args["ContentPublished"], "ContentKeywords": (typeof(args["ContentKeywords"]) !== 'undefined' ? args["ContentKeywords"] : null), "ContentDescription": (typeof(args["ContentDescription"]) !== 'undefined' ? args["ContentDescription"] : null), "ContentRobots": (typeof(args["ContentRobots"]) !== 'undefined' ? args["ContentRobots"] : null), "ContentLanguage": (typeof(args["ContentLanguage"]) !== 'undefined' ? args["ContentLanguage"] : null), "ContentCustom": (typeof(args["ContentCustom"]) !== 'undefined' ? args["ContentCustom"] : null), "ContentAllowMessages": args["ContentAllowMessages"], "ContentAbstract": (typeof(args["ContentAbstract"]) !== 'undefined' ? args["ContentAbstract"] : null), "ParentID": (typeof(args["ParentID"]) !== 'undefined' ? args["ParentID"] : null)}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all articles matching the specified criteria.
        // This code exemplifies how to call the generated function SearchByArticleText
        IEdit.SearchByArticleText(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "dataLike": your_string},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), SiteName (string), SiteRecycleBin (bool), ParentID (int_or_null), ContentType (string)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentTitle"]; 
                    var yourVariable4 = results[i]["ContentPublished"]; 
                    var yourVariable5 = results[i]["ContentSortOrder"]; 
                    var yourVariable6 = results[i]["ContentKeywords"]; 
                    var yourVariable7 = results[i]["ContentDescription"]; 
                    var yourVariable8 = results[i]["ContentRobots"]; 
                    var yourVariable9 = results[i]["ContentLanguage"]; 
                    var yourVariable10 = results[i]["ContentCustom"]; 
                    var yourVariable11 = results[i]["ContentAllowMessages"]; 
                    var yourVariable12 = results[i]["ContentAbstract"]; 
                    var yourVariable13 = results[i]["SiteID"]; 
                    var yourVariable14 = results[i]["SiteName"]; 
                    var yourVariable15 = results[i]["SiteRecycleBin"]; 
                    var yourVariable16 = results[i]["ParentID"]; 
                    var yourVariable17 = results[i]["ContentType"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SearchByArticleText: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SearchByArticleText",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "dataLike": args["dataLike"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all links referring to the specified target.
        // This code exemplifies how to call the generated function SearchByLinkTargetURI
        IEdit.SearchByLinkTargetURI(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "targetURI": your_string},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), SiteName (string), SiteRecycleBin (bool), ParentID (int_or_null), ContentType (string)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentTitle"]; 
                    var yourVariable4 = results[i]["ContentPublished"]; 
                    var yourVariable5 = results[i]["ContentSortOrder"]; 
                    var yourVariable6 = results[i]["ContentKeywords"]; 
                    var yourVariable7 = results[i]["ContentDescription"]; 
                    var yourVariable8 = results[i]["ContentRobots"]; 
                    var yourVariable9 = results[i]["ContentLanguage"]; 
                    var yourVariable10 = results[i]["ContentCustom"]; 
                    var yourVariable11 = results[i]["ContentAllowMessages"]; 
                    var yourVariable12 = results[i]["ContentAbstract"]; 
                    var yourVariable13 = results[i]["SiteID"]; 
                    var yourVariable14 = results[i]["SiteName"]; 
                    var yourVariable15 = results[i]["SiteRecycleBin"]; 
                    var yourVariable16 = results[i]["ParentID"]; 
                    var yourVariable17 = results[i]["ContentType"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SearchByLinkTargetURI: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SearchByLinkTargetURI",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "targetURI": args["targetURI"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Lists all content with a title matching the criteria.
        // This code exemplifies how to call the generated function SearchByTitleType
        IEdit.SearchByTitleType(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "siteID": your_int_or_null, "titleLike": your_string, "typeLike": your_string},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentType (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), ContentAbstract (text_or_null), SiteID (int), SiteName (string), SiteRecycleBin (bool), ParentID (int_or_null)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentType"]; 
                    var yourVariable4 = results[i]["ContentTitle"]; 
                    var yourVariable5 = results[i]["ContentPublished"]; 
                    var yourVariable6 = results[i]["ContentSortOrder"]; 
                    var yourVariable7 = results[i]["ContentKeywords"]; 
                    var yourVariable8 = results[i]["ContentDescription"]; 
                    var yourVariable9 = results[i]["ContentRobots"]; 
                    var yourVariable10 = results[i]["ContentLanguage"]; 
                    var yourVariable11 = results[i]["ContentCustom"]; 
                    var yourVariable12 = results[i]["ContentAllowMessages"]; 
                    var yourVariable13 = results[i]["ContentAbstract"]; 
                    var yourVariable14 = results[i]["SiteID"]; 
                    var yourVariable15 = results[i]["SiteName"]; 
                    var yourVariable16 = results[i]["SiteRecycleBin"]; 
                    var yourVariable17 = results[i]["ParentID"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SearchByTitleType: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SearchByTitleType",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "siteID": (typeof(args["siteID"]) !== 'undefined' ? args["siteID"] : null), "titleLike": args["titleLike"], "typeLike": args["typeLike"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // This code exemplifies how to call the generated function SearchImageByTitle
        IEdit.SearchImageByTitle(
            {"maxRowsToReturn": your_int_or_null, "ticket": your_string_or_null, "siteID": your_int_or_null, "titleLike": your_string},
            function(results, args){
                // This function is called on success
                // results contains: ContentID (int), ContentSUID (string), ContentType (string), ContentTitle (string), ContentPublished (bool), ContentSortOrder (string_or_null), ContentKeywords (string_or_null), ContentDescription (string_or_null), ContentRobots (string_or_null), ContentLanguage (string_or_null), ContentCustom (string_or_null), ContentAllowMessages (bool), SiteID (int), SiteName (string), SiteRecycleBin (bool), ParentID (int_or_null), ContentAbstract (text_or_null), ImageID (int), ImageMimeType (string), ImageWidth (int), ImageHeight (int), ImageAlternative (string_or_null)
                // Example:
                for (var i=0; i<results.length; i++) {
                    var yourVariable1 = results[i]["ContentID"]; 
                    var yourVariable2 = results[i]["ContentSUID"]; 
                    var yourVariable3 = results[i]["ContentType"]; 
                    var yourVariable4 = results[i]["ContentTitle"]; 
                    var yourVariable5 = results[i]["ContentPublished"]; 
                    var yourVariable6 = results[i]["ContentSortOrder"]; 
                    var yourVariable7 = results[i]["ContentKeywords"]; 
                    var yourVariable8 = results[i]["ContentDescription"]; 
                    var yourVariable9 = results[i]["ContentRobots"]; 
                    var yourVariable10 = results[i]["ContentLanguage"]; 
                    var yourVariable11 = results[i]["ContentCustom"]; 
                    var yourVariable12 = results[i]["ContentAllowMessages"]; 
                    var yourVariable13 = results[i]["SiteID"]; 
                    var yourVariable14 = results[i]["SiteName"]; 
                    var yourVariable15 = results[i]["SiteRecycleBin"]; 
                    var yourVariable16 = results[i]["ParentID"]; 
                    var yourVariable17 = results[i]["ContentAbstract"]; 
                    var yourVariable18 = results[i]["ImageID"]; 
                    var yourVariable19 = results[i]["ImageMimeType"]; 
                    var yourVariable20 = results[i]["ImageWidth"]; 
                    var yourVariable21 = results[i]["ImageHeight"]; 
                    var yourVariable22 = results[i]["ImageAlternative"]; 
                }
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    SearchImageByTitle: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/SearchImageByTitle",
            data: IEdit.JSONHelper.SerializeArgs({ "maxRowsToReturn": args["maxRowsToReturn"] || null, "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "siteID": (typeof(args["siteID"]) !== 'undefined' ? args["siteID"] : null), "titleLike": args["titleLike"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var results = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            results = response.d;
                        break;
                        case "PHP":
                            results = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, results, args); else onsuccess(results, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    /*
        // Description: Uploads document or image file. For images, a thumbnail file is automatically generated.
        // This code exemplifies how to call the generated function Upload
        IEdit.Upload(
            {"ticket": your_string_or_null, "siteID": your_int, "contentID": your_int_or_null, "parentID": your_int_or_null, "type": your_string_or_null, "fileName": your_string, "mimeType": your_string, "bytes": your_blob},
            function(result, args){
                // This function is called on success
                // result contains: imageID (int_or_null), documentID (int_or_null)
                // Example:
                var yourVariable1 = result["imageID"]; 
                var yourVariable2 = result["documentID"]; 
            },
            function(x, msg, args){
                // This function is called on error
            },
            function(args){
                // This function is called after onsuccess/onerror
            }
        );
    */

    Upload: function (args, onsuccess, onerror, oncomplete, context) {
        $.ajax({
            type: "POST",
            url: IEdit.wsuri + "/Upload",
            data: IEdit.JSONHelper.SerializeArgs({ "ticket": (typeof(args["ticket"]) !== 'undefined' ? args["ticket"] : null), "siteID": args["siteID"], "contentID": (typeof(args["contentID"]) !== 'undefined' ? args["contentID"] : null), "parentID": (typeof(args["parentID"]) !== 'undefined' ? args["parentID"] : null), "type": (typeof(args["type"]) !== 'undefined' ? args["type"] : null), "fileName": args["fileName"], "mimeType": args["mimeType"], "bytes": args["bytes"]}),
            contentType: "application/json; charset=utf-8",
            dataType: "json",
            success: function(response) {
                if (onsuccess){
                    var result = null;
                    switch(IEdit.JSONHelper.WSEnv()){
                        case ".NET":
                            result = response.d;
                        break;
                        case "PHP":
                            result = response;
                        break;
                        default:
                            throw new Exception("Unknown target environment");
                        break;
                    }
                    if(context) onsuccess.call(context, result, args); else onsuccess(result, args);
                }
            },
            error: function(x, msg) {
                if (onerror){
                    if (context) onerror.call(context, x, msg, args); else onerror(x, msg, args);
                }
            },
            complete: function() {
                if (oncomplete){
                    if (context) oncomplete.call(context, args); else oncomplete(args)
                }
            }
        });
    },

    JSONHelper: {
        SerializeArgs: function (args) {
            var s = [];
            if (args) for (var m in args) s[s.length] = '"' + m + '":' + (typeof(args[m]) == 'undefined' || args[m] == null ? 'null' : (typeof(args[m]) == 'string' ? '"' + args[m].replace(/\\/g,"\\\\").replace(/\"/g, "\\\"").replace(/\r/g,"\\r").replace(/\n/g,"\\n").replace(/\t/g,"\\t") + '"' : args[m].toString()));
            return '{' + s.join(',') + '}';
        },
        WSEnv: function () {
                return (IEdit.wsenvironment && (IEdit.wsenvironment == ".NET" || IEdit.wsenvironment == "PHP") ? IEdit.wsenvironment : (IEdit.wsuri ? (IEdit.wsuri.toLowerCase().match(".asmx$") == ".asmx" ? ".NET" : (IEdit.wsuri.toLowerCase().match(".php$") == ".php" ? "PHP" : "UNKNOWN")) : "UNKNOWN"));
        },
        DateToString: function (date) {
            if(date){
                switch(IEdit.JSONHelper.WSEnv()) {
                    case ".NET":
                    case "PHP": {
                        var pad = function (val) {
                            val = val.toString();
                            while (val.length < 2) val = "0" + val;
                            return val;
                        };
                        return (date ? date.getFullYear() + '-' + pad((date.getMonth()+1)) + '-' + pad(date.getDate()) + 'T' + pad(date.getHours()) + ':' + pad(date.getMinutes()) + ':' + pad(date.getSeconds()) : null);
                    }
                    default:
                        throw new Exception("Unknown target environment");
                }
            }
            return null;
        },
        StringToDate: function (datestring) {
            if(datestring){
                switch(IEdit.JSONHelper.WSEnv()) {
                    case ".NET":
                        return eval('new '+ datestring.replace(/\//g,' '));
                    case "PHP": {
                        var num = function(val, fb) {
                            return (val && val!='' ? parseInt(val,10) : (fb ? fb : 0));
                        };
                        var m = datestring.match(/^\s*((\d\d\d\d)-(\d\d)-(\d\d))((\s|T)(\d\d)(:(\d\d)(:(\d\d))?)?)?\s*$/i);
                        return new Date(num(m[2]), num(m[3])-1, num(m[4]), num(m[7]), num(m[9]), num(m[11]));
                    }
                }
            }
            return null;
        }
    }
}

