﻿using System;
using System.Collections.Generic;
using System.Configuration;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Drawing;
using System.Text.RegularExpressions;
using System.IO;
using cms.DB.IEdit;
using service.Utility;

namespace service
{
    public partial class upload : System.Web.UI.Page
    {
        private List<long> _images = new List<long>();
        private List<long> _docs = new List<long>();
        private bool _success = true;
        private string _error = "";
        private string _jsonp = "";
        private string _ticket = null;

        public bool Success { get { return _success; } }
        public string ErrorMsg { get { return _error; } }
        public string JSONP { get { return _jsonp; } }
        public List<long> Images { get { return _images; } }
        public List<long> Docs { get { return _docs; } }
        public string Ticket { get { return _ticket; } }

        protected void Page_Load(object sender, EventArgs e)
        {
            _ticket = FormUtility.Ticket;
            long? siteID = FormUtility.SiteID;
            long? contentID = FormUtility.ContentID;
            long? parentID = FormUtility.ParentID;
            string type = FormUtility.Type;
            string callback = FormUtility.Callback;
            string cbArgs = FormUtility.GetString("callbackArgs");

            if (siteID.HasValue || contentID.HasValue || parentID.HasValue)
            {
                try
                {
                    IEdit iEdit = new IEdit(FormUtility.Connection);
                    if (contentID.HasValue)
                    {   // Overrides other input
                        returnGetContentDetails content = iEdit.GetContentDetails(Ticket, contentID.Value);
                        siteID = content.SiteID;
                        parentID = content.ParentID;
                    }
                    else if (parentID.HasValue)
                    {   // Overrides siteID input
                        returnGetContentDetails content = iEdit.GetContentDetails(Ticket, parentID.Value);
                        siteID = content.SiteID;
                    }
                    foreach (string ffld in HttpContext.Current.Request.Files.AllKeys)
                    {
                        if (!string.IsNullOrEmpty(HttpContext.Current.Request.Files[ffld].FileName))
                        {
                            byte[] bytes = new byte[Request.Files[ffld].ContentLength];
                            Request.Files[ffld].InputStream.Read(bytes, 0, bytes.Length);
                            returnUpload upload = iEdit.Upload(Ticket, siteID.Value, contentID, parentID, type, Request.Files[ffld].FileName, Request.Files[ffld].ContentType, bytes);
                            if (upload.documentID.HasValue && !_docs.Contains(upload.documentID.Value))
                                _docs.Add(upload.documentID.Value);
                            else if (upload.imageID.HasValue && !_images.Contains(upload.imageID.Value))
                                _images.Add(upload.imageID.Value);
                        }
                    }
                }
                catch (Exception ex)
                {
                    _success = false;
                    _error = ex.Message;
                    throw ex;
                }

                if (!string.IsNullOrEmpty(callback))
                {
                    _jsonp = callback + "({\"images\":[" + FormUtility.Join(_images) + "],\"documents\":[" + FormUtility.Join(_docs) + "],\"success\":" + _success.ToString().ToLower() + "}" + (!string.IsNullOrEmpty(cbArgs) ? "," + cbArgs : "") + ");";
                }
            }
        }
    }
}
