﻿using System;
using System.Collections.Generic;
using System.Text.RegularExpressions;
using System.Web;
using cms.DB.PPlatform;

namespace service.Utility
{
    public class FormUtility
    {
        public static string Connection { get { return System.Configuration.ConfigurationManager.AppSettings["cms"]; } }
        public static string Ticket { get { return FormUtility.GetCookie(System.Configuration.ConfigurationManager.AppSettings["cookie"], "ticket"); } }
        public static string Type { get { return FormUtility.GetString("type"); } }
        public static string Callback { get { return FormUtility.GetString("callback"); } }
        public static long? ParentID { get { return FormUtility.GetID("parent"); } }
        public static long? SiteID { get { return FormUtility.GetID("site"); } }
        public static long? ContentID
        {
            get
            {
                long? contentID = FormUtility.GetID("content");
                if (!contentID.HasValue)
                {   // Try finding content by SUID or FN instead
                    PPlatform pPF = new PPlatform(Connection);
                    long lookupContentID = pPF.FindIDBySUID(GetString("suid")).ContentID;
                    if (lookupContentID == 0)
                        lookupContentID = pPF.FindIDByFriendlyName(GetString("fn")).ContentID;
                    if (lookupContentID != 0)
                        contentID = lookupContentID;
                }
                return contentID;
            }
        }

        public static long? GetID(string idName)
        {
            long? id = null;
            string s = GetString(idName);
            if (!string.IsNullOrEmpty(s))
            {
                long l = 0;
                long.TryParse(s, out l);
                if (l == 0)
                {   // Value isn't an ID, check if friendly name or SUID
                    PPlatform pPF = new PPlatform(Connection);
                    l = pPF.FindIDByFriendlyName(s).ContentID;
                    if (l == 0)
                        l = pPF.FindIDBySUID(s).ContentID;
                }
                if (l != 0)
                    id = l;
            }
            return id;
        }

        public static string GetCookie(string cookieName, string fallback)
        {
            string cookieValue = null;
            if (HttpContext.Current.Request.Cookies[cookieName] != null)
            {
                cookieValue = HttpContext.Current.Request.Cookies[cookieName].Value;
            }
            string str = GetString(fallback);
            if (string.IsNullOrEmpty(str))
                str = cookieValue;
            else if (!string.IsNullOrEmpty(cookieValue) && str != cookieValue)
                str = null; // collision
            return str;
        }

        public static string GetString(string stringName)
        {
            string str = FormUtility.SafeForm(new List<string>(HttpContext.Current.Request.Form.AllKeys).Find(delegate(string cmp) { return cmp.EndsWith(stringName); }));
            if (string.IsNullOrEmpty(str) && !string.IsNullOrEmpty(HttpContext.Current.Request.QueryString[stringName])) 
                str = HttpContext.Current.Request.QueryString[stringName];
            return str;
        }

        public static bool GetFlag(string flagName)
        {
            string str = FormUtility.SafeForm(new List<string>(HttpContext.Current.Request.Form.AllKeys).Find(delegate(string cmp) { return cmp.EndsWith(flagName); }));
            if (string.IsNullOrEmpty(str) && !string.IsNullOrEmpty(HttpContext.Current.Request.QueryString[flagName]))
                str = HttpContext.Current.Request.QueryString[flagName];
            return !string.IsNullOrEmpty(str) && (str=="1" || str.ToLower()=="yes" || str.ToLower()=="true" || str.ToLower()=="on");
        }

        public static string Join(List<long> list)
        {
            string js = string.Empty;
            foreach (long id in list) js += (!string.IsNullOrEmpty(js) ? "," : "") + id.ToString();
            return js;
        }

        public static string AddQueryStringPair(string url, string name, string value)
        {
            Regex rx = new Regex("[?&]" + HttpUtility.UrlEncode(name) + "=[^&]*", RegexOptions.IgnoreCase);
            Match m = rx.Match(url);
            if (m.Success)
            {
                return url.Substring(0, m.Index + 1) + HttpUtility.UrlEncode(name) + "=" + HttpUtility.UrlEncode(value) + url.Substring(m.Index + m.Length);
            }
            return url + (url.Contains("?") ? "&" : "?") + HttpUtility.UrlEncode(name) + "=" + HttpUtility.UrlEncode(value);
        }

        protected static long? SafeForm64(string key)
        {
            string s = SafeForm(key);
            return (!string.IsNullOrEmpty(s) ? (long?)Convert.ToInt64(s) : null);
        }

        protected static string SafeForm(string key)
        {
            return (!string.IsNullOrEmpty(key) ? HttpContext.Current.Request.Form[key] : null);
        }
    }
}